/* Generated by wayland-scanner 1.26.0 */

#ifndef QT_VULKAN_SERVER_BUFFER_UNSTABLE_V1_SERVER_PROTOCOL_H
#define QT_VULKAN_SERVER_BUFFER_UNSTABLE_V1_SERVER_PROTOCOL_H

#include <stdint.h>
#include <stddef.h>
#include "wayland-server-core.h"

#ifdef  __cplusplus
extern "C" {
#endif

struct wl_client;
struct wl_resource;

/**
 * @page page_qt_vulkan_server_buffer_unstable_v1 The qt_vulkan_server_buffer_unstable_v1 protocol
 * @section page_ifaces_qt_vulkan_server_buffer_unstable_v1 Interfaces
 * - @subpage page_iface_zqt_vulkan_server_buffer_v1 - Internal protocol for buffer sharing using Vulkan external memory
 * @section page_copyright_qt_vulkan_server_buffer_unstable_v1 Copyright
 * <pre>
 *
 * Copyright (C) 2019 The Qt Company Ltd.
 * SPDX-License-Identifier: LicenseRef-Qt-Commercial OR BSD-3-Clause
 * </pre>
 */
struct qt_server_buffer;
struct zqt_vulkan_server_buffer_v1;

#ifndef ZQT_VULKAN_SERVER_BUFFER_V1_INTERFACE
#define ZQT_VULKAN_SERVER_BUFFER_V1_INTERFACE
/**
 * @page page_iface_zqt_vulkan_server_buffer_v1 zqt_vulkan_server_buffer_v1
 * @section page_iface_zqt_vulkan_server_buffer_v1_desc Description
 *
 * This protocol is used internally by Qt for implementing the
 * qt_server_buffer extension on hardware that supports Vulkan external memory .
 *
 * This protocol is not part of the Qt API.  It exists purely as an
 * implementation detail and may change from version to
 * version without notice, or even be removed.
 * @section page_iface_zqt_vulkan_server_buffer_v1_api API
 * See @ref iface_zqt_vulkan_server_buffer_v1.
 */
/**
 * @defgroup iface_zqt_vulkan_server_buffer_v1 The zqt_vulkan_server_buffer_v1 interface
 *
 * This protocol is used internally by Qt for implementing the
 * qt_server_buffer extension on hardware that supports Vulkan external memory .
 *
 * This protocol is not part of the Qt API.  It exists purely as an
 * implementation detail and may change from version to
 * version without notice, or even be removed.
 */
extern const struct wl_interface zqt_vulkan_server_buffer_v1_interface;
#endif

#define ZQT_VULKAN_SERVER_BUFFER_V1_SERVER_BUFFER_CREATED 0

/**
 * @ingroup iface_zqt_vulkan_server_buffer_v1
 */
#define ZQT_VULKAN_SERVER_BUFFER_V1_SERVER_BUFFER_CREATED_SINCE_VERSION 1


/**
 * @ingroup iface_zqt_vulkan_server_buffer_v1
 * Sends an server_buffer_created event to the client owning the resource.
 * @param resource_ The client's resource
 * @param fd GL_EXT_memory_object_fd
 * @param memory_size size in bytes
 * @param format GL internal format
 */
static inline void
zqt_vulkan_server_buffer_v1_send_server_buffer_created(struct wl_resource *resource_, struct wl_resource *id, int32_t fd, uint32_t width, uint32_t height, uint32_t memory_size, uint32_t format)
{
	wl_resource_post_event(resource_, ZQT_VULKAN_SERVER_BUFFER_V1_SERVER_BUFFER_CREATED, id, fd, width, height, memory_size, format);
}

#ifdef  __cplusplus
}
#endif

#endif
