/* Generated by wayland-scanner 1.26.0 */

/*
 * Copyright (C) 2021 The Qt Company Ltd.
 * SPDX-License-Identifier: LicenseRef-Qt-Commercial OR BSD-3-Clause
 */

#include <stdbool.h>
#include <stdlib.h>
#include <stdint.h>
#include "wayland-util.h"

#ifndef __has_attribute
# define __has_attribute(x) 0  /* Compatibility with non-clang compilers. */
#endif

#if (__has_attribute(visibility) || defined(__GNUC__) && __GNUC__ >= 4)
#define WL_PRIVATE __attribute__ ((visibility("hidden")))
#else
#define WL_PRIVATE
#endif

extern const struct wl_interface wl_surface_interface;
extern const struct wl_interface zqt_shell_surface_v1_interface;

static const struct wl_interface *qt_shell_unstable_v1_types[] = {
	NULL,
	NULL,
	NULL,
	NULL,
	&wl_surface_interface,
	&zqt_shell_surface_v1_interface,
};

static const struct wl_message zqt_shell_surface_v1_requests[] = {
	{ "destroy", "", qt_shell_unstable_v1_types + 0 },
	{ "reposition", "ii", qt_shell_unstable_v1_types + 0 },
	{ "request_activate", "", qt_shell_unstable_v1_types + 0 },
	{ "set_size", "ii", qt_shell_unstable_v1_types + 0 },
	{ "set_minimum_size", "ii", qt_shell_unstable_v1_types + 0 },
	{ "set_maximum_size", "ii", qt_shell_unstable_v1_types + 0 },
	{ "set_window_title", "s", qt_shell_unstable_v1_types + 0 },
	{ "set_window_flags", "u", qt_shell_unstable_v1_types + 0 },
	{ "start_system_resize", "uu", qt_shell_unstable_v1_types + 0 },
	{ "start_system_move", "u", qt_shell_unstable_v1_types + 0 },
	{ "change_window_state", "u", qt_shell_unstable_v1_types + 0 },
	{ "raise", "", qt_shell_unstable_v1_types + 0 },
	{ "lower", "", qt_shell_unstable_v1_types + 0 },
	{ "ack_configure", "u", qt_shell_unstable_v1_types + 0 },
};

static const struct wl_message zqt_shell_surface_v1_events[] = {
	{ "resize", "uii", qt_shell_unstable_v1_types + 0 },
	{ "set_position", "uii", qt_shell_unstable_v1_types + 0 },
	{ "set_window_state", "uu", qt_shell_unstable_v1_types + 0 },
	{ "configure", "u", qt_shell_unstable_v1_types + 0 },
	{ "set_frame_margins", "uuuu", qt_shell_unstable_v1_types + 0 },
	{ "close", "", qt_shell_unstable_v1_types + 0 },
	{ "set_capabilities", "u", qt_shell_unstable_v1_types + 0 },
};

WL_PRIVATE const struct wl_interface zqt_shell_surface_v1_interface = {
	"zqt_shell_surface_v1", 1,
	14, zqt_shell_surface_v1_requests,
	7, zqt_shell_surface_v1_events,
};

static const struct wl_message zqt_shell_v1_requests[] = {
	{ "surface_create", "on", qt_shell_unstable_v1_types + 4 },
};

WL_PRIVATE const struct wl_interface zqt_shell_v1_interface = {
	"zqt_shell_v1", 1,
	1, zqt_shell_v1_requests,
	0, NULL,
};

