/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<qwaylandqtshell.h>)
#  include <qwaylandqtshell.h>
#endif
#if __has_include(<qwaylandqtshellchrome.h>)
#  include <qwaylandqtshellchrome.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_QtWayland_Compositor_QtShell()
{
    qmlRegisterModule("QtWayland.Compositor.QtShell", 1, 0);
    qmlRegisterModule("QtWayland.Compositor.QtShell", 1, 254);
    qmlRegisterModule("QtWayland.Compositor.QtShell", 6, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    QMetaType::fromType<QWaylandQtShell *>().id();
    qmlRegisterTypesAndRevisions<QWaylandQtShellChrome>("QtWayland.Compositor.QtShell", 6);
    qmlRegisterAnonymousTypesAndRevisions<QQuickItem>("QtWayland.Compositor.QtShell", 6);
    qmlRegisterTypesAndRevisions<QWaylandQtShellQuickExtension>("QtWayland.Compositor.QtShell", 6);
    qmlRegisterTypesAndRevisions<QWaylandQtShellSurface>("QtWayland.Compositor.QtShell", 6);
    qmlRegisterEnum<QWaylandQtShellSurface::CapabilityFlag>("QWaylandQtShellSurface::CapabilityFlag");
    QT_WARNING_POP
    qmlRegisterModule("QtWayland.Compositor.QtShell", 6, 12);
}

static const QQmlModuleRegistration qtWaylandCompositorQtShellRegistration("QtWayland.Compositor.QtShell", qml_register_types_QtWayland_Compositor_QtShell);
