/****************************************************************************
** Meta object code from reading C++ file 'qwaylandcompositor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtwayland/src/compositor/compositor_api/qwaylandcompositor.h"
#include "qwaylandseat.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qwaylandcompositor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18QWaylandCompositorE_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandCompositor::qt_create_metaobjectdata<qt_meta_tag_ZN18QWaylandCompositorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandCompositor",
        "QML.Element",
        "WaylandCompositorBase",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Cannot create instance of WaylandCompositorBase, use WaylandCompos"
        "itor instead",
        "QML.AddedInVersion",
        "256",
        "createdChanged",
        "",
        "socketNameChanged",
        "socketName",
        "retainedSelectionChanged",
        "retainedSelection",
        "surfaceRequested",
        "QWaylandClient*",
        "client",
        "id",
        "version",
        "surfaceCreated",
        "QWaylandSurface*",
        "surface",
        "surfaceAboutToBeDestroyed",
        "subsurfaceChanged",
        "child",
        "parent",
        "defaultOutputChanged",
        "defaultSeatChanged",
        "QWaylandSeat*",
        "newDevice",
        "oldDevice",
        "useHardwareIntegrationExtensionChanged",
        "outputAdded",
        "QWaylandOutput*",
        "output",
        "outputRemoved",
        "additionalShmFormatsChanged",
        "processWaylandEvents",
        "applicationStateChanged",
        "Qt::ApplicationState",
        "state",
        "addSocketDescriptor",
        "fd",
        "destroyClientForSurface",
        "destroyClient",
        "outputFor",
        "QWindow*",
        "window",
        "created",
        "defaultOutput",
        "useHardwareIntegrationExtension",
        "defaultSeat",
        "additionalShmFormats",
        "QList<ShmFormat>",
        "ShmFormat",
        "ShmFormat_ARGB8888",
        "ShmFormat_XRGB8888",
        "ShmFormat_C8",
        "ShmFormat_XRGB4444",
        "ShmFormat_ARGB4444",
        "ShmFormat_XRGB1555",
        "ShmFormat_RGB565",
        "ShmFormat_RGB888",
        "ShmFormat_XBGR8888",
        "ShmFormat_ABGR8888",
        "ShmFormat_BGR888",
        "ShmFormat_XRGB2101010",
        "ShmFormat_XBGR2101010",
        "ShmFormat_ARGB2101010",
        "ShmFormat_ABGR2101010"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'createdChanged'
        QtMocHelpers::SignalData<void()>(9, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'socketNameChanged'
        QtMocHelpers::SignalData<void(const QByteArray &)>(11, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 12 },
        }}),
        // Signal 'retainedSelectionChanged'
        QtMocHelpers::SignalData<void(bool)>(13, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'surfaceRequested'
        QtMocHelpers::SignalData<void(QWaylandClient *, uint, int)>(15, 10, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 }, { QMetaType::UInt, 18 }, { QMetaType::Int, 19 },
        }}),
        // Signal 'surfaceCreated'
        QtMocHelpers::SignalData<void(QWaylandSurface *)>(20, 10, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Signal 'surfaceAboutToBeDestroyed'
        QtMocHelpers::SignalData<void(QWaylandSurface *)>(23, 10, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Signal 'subsurfaceChanged'
        QtMocHelpers::SignalData<void(QWaylandSurface *, QWaylandSurface *)>(24, 10, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 25 }, { 0x80000000 | 21, 26 },
        }}),
        // Signal 'defaultOutputChanged'
        QtMocHelpers::SignalData<void()>(27, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultSeatChanged'
        QtMocHelpers::SignalData<void(QWaylandSeat *, QWaylandSeat *)>(28, 10, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 }, { 0x80000000 | 29, 31 },
        }}),
        // Signal 'useHardwareIntegrationExtensionChanged'
        QtMocHelpers::SignalData<void()>(32, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputAdded'
        QtMocHelpers::SignalData<void(QWaylandOutput *)>(33, 10, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 35 },
        }}),
        // Signal 'outputRemoved'
        QtMocHelpers::SignalData<void(QWaylandOutput *)>(36, 10, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 35 },
        }}),
        // Signal 'additionalShmFormatsChanged'
        QtMocHelpers::SignalData<void()>(37, 10, QMC::AccessPublic, QMetaType::Void),
        // Slot 'processWaylandEvents'
        QtMocHelpers::SlotData<void()>(38, 10, QMC::AccessPublic, QMetaType::Void),
        // Slot 'applicationStateChanged'
        QtMocHelpers::SlotData<void(Qt::ApplicationState)>(39, 10, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 40, 41 },
        }}),
        // Method 'addSocketDescriptor'
        QtMocHelpers::MethodData<void(int)>(42, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 43 },
        }}),
        // Method 'destroyClientForSurface'
        QtMocHelpers::MethodData<void(QWaylandSurface *)>(44, 10, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Method 'destroyClient'
        QtMocHelpers::MethodData<void(QWaylandClient *)>(45, 10, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Method 'outputFor'
        QtMocHelpers::MethodData<QWaylandOutput *(QWindow *) const>(46, 10, QMC::AccessPublic, 0x80000000 | 34, {{
            { 0x80000000 | 47, 48 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'socketName'
        QtMocHelpers::PropertyData<QByteArray>(12, QMetaType::QByteArray, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'created'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'retainedSelection'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'defaultOutput'
        QtMocHelpers::PropertyData<QWaylandOutput*>(50, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'useHardwareIntegrationExtension'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'defaultSeat'
        QtMocHelpers::PropertyData<QWaylandSeat*>(52, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 8),
        // property 'additionalShmFormats'
        QtMocHelpers::PropertyData<QList<ShmFormat>>(53, 0x80000000 | 54, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 12, 0x600),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ShmFormat'
        QtMocHelpers::EnumData<enum ShmFormat>(55, 55, QMC::EnumFlags{}).add({
            {   56, ShmFormat::ShmFormat_ARGB8888 },
            {   57, ShmFormat::ShmFormat_XRGB8888 },
            {   58, ShmFormat::ShmFormat_C8 },
            {   59, ShmFormat::ShmFormat_XRGB4444 },
            {   60, ShmFormat::ShmFormat_ARGB4444 },
            {   61, ShmFormat::ShmFormat_XRGB1555 },
            {   62, ShmFormat::ShmFormat_RGB565 },
            {   63, ShmFormat::ShmFormat_RGB888 },
            {   64, ShmFormat::ShmFormat_XBGR8888 },
            {   65, ShmFormat::ShmFormat_ABGR8888 },
            {   66, ShmFormat::ShmFormat_BGR888 },
            {   67, ShmFormat::ShmFormat_XRGB2101010 },
            {   68, ShmFormat::ShmFormat_XBGR2101010 },
            {   69, ShmFormat::ShmFormat_ARGB2101010 },
            {   70, ShmFormat::ShmFormat_ABGR2101010 },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<QWaylandCompositor, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QWaylandCompositor::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18QWaylandCompositorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18QWaylandCompositorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18QWaylandCompositorE_t>.metaTypes,
    nullptr
} };

void QWaylandCompositor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QWaylandCompositor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->createdChanged(); break;
        case 1: _t->socketNameChanged((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 2: _t->retainedSelectionChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->surfaceRequested((*reinterpret_cast<std::add_pointer_t<QWaylandClient*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 4: _t->surfaceCreated((*reinterpret_cast<std::add_pointer_t<QWaylandSurface*>>(_a[1]))); break;
        case 5: _t->surfaceAboutToBeDestroyed((*reinterpret_cast<std::add_pointer_t<QWaylandSurface*>>(_a[1]))); break;
        case 6: _t->subsurfaceChanged((*reinterpret_cast<std::add_pointer_t<QWaylandSurface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWaylandSurface*>>(_a[2]))); break;
        case 7: _t->defaultOutputChanged(); break;
        case 8: _t->defaultSeatChanged((*reinterpret_cast<std::add_pointer_t<QWaylandSeat*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWaylandSeat*>>(_a[2]))); break;
        case 9: _t->useHardwareIntegrationExtensionChanged(); break;
        case 10: _t->outputAdded((*reinterpret_cast<std::add_pointer_t<QWaylandOutput*>>(_a[1]))); break;
        case 11: _t->outputRemoved((*reinterpret_cast<std::add_pointer_t<QWaylandOutput*>>(_a[1]))); break;
        case 12: _t->additionalShmFormatsChanged(); break;
        case 13: _t->processWaylandEvents(); break;
        case 14: _t->applicationStateChanged((*reinterpret_cast<std::add_pointer_t<Qt::ApplicationState>>(_a[1]))); break;
        case 15: _t->addSocketDescriptor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->destroyClientForSurface((*reinterpret_cast<std::add_pointer_t<QWaylandSurface*>>(_a[1]))); break;
        case 17: _t->destroyClient((*reinterpret_cast<std::add_pointer_t<QWaylandClient*>>(_a[1]))); break;
        case 18: { QWaylandOutput* _r = _t->outputFor((*reinterpret_cast<std::add_pointer_t<QWindow*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QWaylandOutput**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWaylandOutput* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWaylandOutput* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QWaylandCompositor::*)()>(_a, &QWaylandCompositor::createdChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandCompositor::*)(const QByteArray & )>(_a, &QWaylandCompositor::socketNameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandCompositor::*)(bool )>(_a, &QWaylandCompositor::retainedSelectionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandCompositor::*)(QWaylandClient * , uint , int )>(_a, &QWaylandCompositor::surfaceRequested, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandCompositor::*)(QWaylandSurface * )>(_a, &QWaylandCompositor::surfaceCreated, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandCompositor::*)(QWaylandSurface * )>(_a, &QWaylandCompositor::surfaceAboutToBeDestroyed, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandCompositor::*)(QWaylandSurface * , QWaylandSurface * )>(_a, &QWaylandCompositor::subsurfaceChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandCompositor::*)()>(_a, &QWaylandCompositor::defaultOutputChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandCompositor::*)(QWaylandSeat * , QWaylandSeat * )>(_a, &QWaylandCompositor::defaultSeatChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandCompositor::*)()>(_a, &QWaylandCompositor::useHardwareIntegrationExtensionChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandCompositor::*)(QWaylandOutput * )>(_a, &QWaylandCompositor::outputAdded, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandCompositor::*)(QWaylandOutput * )>(_a, &QWaylandCompositor::outputRemoved, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandCompositor::*)()>(_a, &QWaylandCompositor::additionalShmFormatsChanged, 12))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWaylandOutput* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QByteArray*>(_v) = _t->socketName(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isCreated(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->retainedSelectionEnabled(); break;
        case 3: *reinterpret_cast<QWaylandOutput**>(_v) = _t->defaultOutput(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->useHardwareIntegrationExtension(); break;
        case 5: *reinterpret_cast<QWaylandSeat**>(_v) = _t->defaultSeat(); break;
        case 6: *reinterpret_cast<QList<ShmFormat>*>(_v) = _t->additionalShmFormats(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSocketName(*reinterpret_cast<QByteArray*>(_v)); break;
        case 2: _t->setRetainedSelectionEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setDefaultOutput(*reinterpret_cast<QWaylandOutput**>(_v)); break;
        case 4: _t->setUseHardwareIntegrationExtension(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setAdditionalShmFormats(*reinterpret_cast<QList<ShmFormat>*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QWaylandCompositor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QWaylandCompositor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18QWaylandCompositorE_t>.strings))
        return static_cast<void*>(this);
    return QWaylandObject::qt_metacast(_clname);
}

int QWaylandCompositor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void QWaylandCompositor::createdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QWaylandCompositor::socketNameChanged(const QByteArray & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void QWaylandCompositor::retainedSelectionChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void QWaylandCompositor::surfaceRequested(QWaylandClient * _t1, uint _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void QWaylandCompositor::surfaceCreated(QWaylandSurface * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void QWaylandCompositor::surfaceAboutToBeDestroyed(QWaylandSurface * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void QWaylandCompositor::subsurfaceChanged(QWaylandSurface * _t1, QWaylandSurface * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void QWaylandCompositor::defaultOutputChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QWaylandCompositor::defaultSeatChanged(QWaylandSeat * _t1, QWaylandSeat * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void QWaylandCompositor::useHardwareIntegrationExtensionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QWaylandCompositor::outputAdded(QWaylandOutput * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void QWaylandCompositor::outputRemoved(QWaylandOutput * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void QWaylandCompositor::additionalShmFormatsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}
QT_WARNING_POP
