/****************************************************************************
** Meta object code from reading C++ file 'qwaylandwlshellintegration_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtwayland/src/compositor/extensions/qwaylandwlshellintegration_p.h"
#include <QtNetwork/QSslError>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qwaylandwlshellintegration_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9QtWayland18WlShellIntegrationE_t {};
} // unnamed namespace

template <> constexpr inline auto QtWayland::WlShellIntegration::qt_create_metaobjectdata<qt_meta_tag_ZN9QtWayland18WlShellIntegrationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QtWayland::WlShellIntegration",
        "handleStartMove",
        "",
        "QWaylandSeat*",
        "seat",
        "handleStartResize",
        "QWaylandWlShellSurface::ResizeEdge",
        "edges",
        "handleSetDefaultTopLevel",
        "handleSetTransient",
        "QWaylandSurface*",
        "parentSurface",
        "QPoint",
        "relativeToParent",
        "inactive",
        "handleSetMaximized",
        "QWaylandOutput*",
        "output",
        "handleSetFullScreen",
        "QWaylandWlShellSurface::FullScreenMethod",
        "method",
        "framerate",
        "handleSetPopup",
        "parent",
        "handleShellSurfaceDestroyed",
        "handleSurfaceHasContentChanged",
        "handleRedraw",
        "adjustOffsetForNextFrame",
        "QPointF",
        "offset",
        "handleFullScreenSizeChanged",
        "handleMaximizedSizeChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'handleStartMove'
        QtMocHelpers::SlotData<void(QWaylandSeat *)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'handleStartResize'
        QtMocHelpers::SlotData<void(QWaylandSeat *, QWaylandWlShellSurface::ResizeEdge)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'handleSetDefaultTopLevel'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleSetTransient'
        QtMocHelpers::SlotData<void(QWaylandSurface *, const QPoint &, bool)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 }, { QMetaType::Bool, 14 },
        }}),
        // Slot 'handleSetMaximized'
        QtMocHelpers::SlotData<void(QWaylandOutput *)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'handleSetFullScreen'
        QtMocHelpers::SlotData<void(QWaylandWlShellSurface::FullScreenMethod, uint, QWaylandOutput *)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { QMetaType::UInt, 21 }, { 0x80000000 | 16, 17 },
        }}),
        // Slot 'handleSetPopup'
        QtMocHelpers::SlotData<void(QWaylandSeat *, QWaylandSurface *, const QPoint &)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 10, 23 }, { 0x80000000 | 12, 13 },
        }}),
        // Slot 'handleShellSurfaceDestroyed'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleSurfaceHasContentChanged'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleRedraw'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'adjustOffsetForNextFrame'
        QtMocHelpers::SlotData<void(const QPointF &)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'handleFullScreenSizeChanged'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleMaximizedSizeChanged'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WlShellIntegration, qt_meta_tag_ZN9QtWayland18WlShellIntegrationE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QtWayland::WlShellIntegration::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandQuickShellIntegration::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QtWayland18WlShellIntegrationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QtWayland18WlShellIntegrationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9QtWayland18WlShellIntegrationE_t>.metaTypes,
    nullptr
} };

void QtWayland::WlShellIntegration::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WlShellIntegration *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->handleStartMove((*reinterpret_cast<std::add_pointer_t<QWaylandSeat*>>(_a[1]))); break;
        case 1: _t->handleStartResize((*reinterpret_cast<std::add_pointer_t<QWaylandSeat*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWaylandWlShellSurface::ResizeEdge>>(_a[2]))); break;
        case 2: _t->handleSetDefaultTopLevel(); break;
        case 3: _t->handleSetTransient((*reinterpret_cast<std::add_pointer_t<QWaylandSurface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 4: _t->handleSetMaximized((*reinterpret_cast<std::add_pointer_t<QWaylandOutput*>>(_a[1]))); break;
        case 5: _t->handleSetFullScreen((*reinterpret_cast<std::add_pointer_t<QWaylandWlShellSurface::FullScreenMethod>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QWaylandOutput*>>(_a[3]))); break;
        case 6: _t->handleSetPopup((*reinterpret_cast<std::add_pointer_t<QWaylandSeat*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWaylandSurface*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[3]))); break;
        case 7: _t->handleShellSurfaceDestroyed(); break;
        case 8: _t->handleSurfaceHasContentChanged(); break;
        case 9: _t->handleRedraw(); break;
        case 10: _t->adjustOffsetForNextFrame((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 11: _t->handleFullScreenSizeChanged(); break;
        case 12: _t->handleMaximizedSizeChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWaylandSurface* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWaylandOutput* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWaylandOutput* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWaylandSurface* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *QtWayland::WlShellIntegration::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QtWayland::WlShellIntegration::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QtWayland18WlShellIntegrationE_t>.strings))
        return static_cast<void*>(this);
    return QWaylandQuickShellIntegration::qt_metacast(_clname);
}

int QtWayland::WlShellIntegration::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandQuickShellIntegration::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}
QT_WARNING_POP
