/****************************************************************************
** Meta object code from reading C++ file 'qwaylandquickitem.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtwayland/src/compositor/compositor_api/qwaylandquickitem.h"
#include "qwaylandcompositor.h"
#include "qwaylandseat.h"
#include "qwaylanddrag.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qwaylandquickitem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17QWaylandQuickItemE_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandQuickItem::qt_create_metaobjectdata<qt_meta_tag_ZN17QWaylandQuickItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandQuickItem",
        "QML.Element",
        "WaylandQuickItem",
        "QML.AddedInVersion",
        "256",
        "surfaceChanged",
        "",
        "compositorChanged",
        "paintEnabledChanged",
        "touchEventsEnabledChanged",
        "originChanged",
        "surfaceDestroyed",
        "inputEventsEnabledChanged",
        "focusOnClickChanged",
        "mouseMove",
        "QPointF",
        "windowPosition",
        "mouseRelease",
        "subsurfaceHandlerChanged",
        "outputChanged",
        "bufferLockedChanged",
        "allowDiscardFrontBufferChanged",
        "takeFocus",
        "QWaylandSeat*",
        "device",
        "setPaintEnabled",
        "paintEnabled",
        "raise",
        "lower",
        "sendMouseMoveEvent",
        "position",
        "seat",
        "surfaceMappedChanged",
        "handleSurfaceChanged",
        "handleBufferLockedChanged",
        "parentChanged",
        "QWaylandSurface*",
        "newParent",
        "oldParent",
        "updateSize",
        "updateBuffer",
        "hasBuffer",
        "updateWindow",
        "updateOutput",
        "beforeSync",
        "handleSubsurfaceAdded",
        "childSurface",
        "handleSubsurfacePosition",
        "QPoint",
        "pos",
        "handlePlaceAbove",
        "referenceSurface",
        "handlePlaceBelow",
        "handleDragStarted",
        "QWaylandDrag*",
        "drag",
        "updateInputMethod",
        "Qt::InputMethodQueries",
        "queries",
        "updateFocus",
        "mapToSurface",
        "point",
        "mapFromSurface",
        "inputMethodQuery",
        "QVariant",
        "Qt::InputMethodQuery",
        "query",
        "argument",
        "setPrimary",
        "compositor",
        "QWaylandCompositor*",
        "surface",
        "touchEventsEnabled",
        "origin",
        "QWaylandSurface::Origin",
        "inputEventsEnabled",
        "focusOnClick",
        "subsurfaceHandler",
        "output",
        "QWaylandOutput*",
        "bufferLocked",
        "allowDiscardFrontBuffer"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'surfaceChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'compositorChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paintEnabledChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'touchEventsEnabledChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'originChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'surfaceDestroyed'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputEventsEnabledChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusOnClickChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mouseMove'
        QtMocHelpers::SignalData<void(const QPointF &)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'mouseRelease'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'subsurfaceHandlerChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bufferLockedChanged'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'allowDiscardFrontBufferChanged'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'takeFocus'
        QtMocHelpers::SlotData<void(QWaylandSeat *)>(22, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'takeFocus'
        QtMocHelpers::SlotData<void()>(22, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setPaintEnabled'
        QtMocHelpers::SlotData<void(bool)>(25, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'raise'
        QtMocHelpers::SlotData<void()>(27, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'lower'
        QtMocHelpers::SlotData<void()>(28, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sendMouseMoveEvent'
        QtMocHelpers::SlotData<void(const QPointF &, QWaylandSeat *)>(29, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 30 }, { 0x80000000 | 23, 31 },
        }}),
        // Slot 'sendMouseMoveEvent'
        QtMocHelpers::SlotData<void(const QPointF &)>(29, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 15, 30 },
        }}),
        // Slot 'surfaceMappedChanged'
        QtMocHelpers::SlotData<void()>(32, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleSurfaceChanged'
        QtMocHelpers::SlotData<void()>(33, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleBufferLockedChanged'
        QtMocHelpers::SlotData<void()>(34, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'parentChanged'
        QtMocHelpers::SlotData<void(QWaylandSurface *, QWaylandSurface *)>(35, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 36, 37 }, { 0x80000000 | 36, 38 },
        }}),
        // Slot 'updateSize'
        QtMocHelpers::SlotData<void()>(39, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateBuffer'
        QtMocHelpers::SlotData<void(bool)>(40, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'updateWindow'
        QtMocHelpers::SlotData<void()>(42, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateOutput'
        QtMocHelpers::SlotData<void()>(43, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'beforeSync'
        QtMocHelpers::SlotData<void()>(44, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleSubsurfaceAdded'
        QtMocHelpers::SlotData<void(QWaylandSurface *)>(45, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 36, 46 },
        }}),
        // Slot 'handleSubsurfacePosition'
        QtMocHelpers::SlotData<void(const QPoint &)>(47, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 48, 49 },
        }}),
        // Slot 'handlePlaceAbove'
        QtMocHelpers::SlotData<void(QWaylandSurface *)>(50, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 36, 51 },
        }}),
        // Slot 'handlePlaceBelow'
        QtMocHelpers::SlotData<void(QWaylandSurface *)>(52, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 36, 51 },
        }}),
        // Slot 'handleDragStarted'
        QtMocHelpers::SlotData<void(QWaylandDrag *)>(53, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 54, 55 },
        }}),
        // Slot 'updateInputMethod'
        QtMocHelpers::SlotData<void(Qt::InputMethodQueries)>(56, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 57, 58 },
        }}),
        // Slot 'updateFocus'
        QtMocHelpers::SlotData<void()>(59, 6, QMC::AccessPrivate, QMetaType::Void),
        // Method 'mapToSurface'
        QtMocHelpers::MethodData<QPointF(const QPointF &) const>(60, 6, QMC::AccessPublic, 0x80000000 | 15, {{
            { 0x80000000 | 15, 61 },
        }}),
        // Method 'mapFromSurface'
        QtMocHelpers::RevisionedMethodData<QPointF(const QPointF &) const>(62, 6, QMC::AccessPublic, 0x10d, 0x80000000 | 15, {{
            { 0x80000000 | 15, 61 },
        }}),
        // Method 'inputMethodQuery'
        QtMocHelpers::MethodData<QVariant(Qt::InputMethodQuery, QVariant) const>(63, 6, QMC::AccessPublic, 0x80000000 | 64, {{
            { 0x80000000 | 65, 66 }, { 0x80000000 | 64, 67 },
        }}),
        // Method 'setPrimary'
        QtMocHelpers::MethodData<void()>(68, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'compositor'
        QtMocHelpers::PropertyData<QWaylandCompositor*>(69, 0x80000000 | 70, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'surface'
        QtMocHelpers::PropertyData<QWaylandSurface*>(71, 0x80000000 | 36, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'paintEnabled'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'touchEventsEnabled'
        QtMocHelpers::PropertyData<bool>(72, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'origin'
        QtMocHelpers::PropertyData<QWaylandSurface::Origin>(73, 0x80000000 | 74, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'inputEventsEnabled'
        QtMocHelpers::PropertyData<bool>(75, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'focusOnClick'
        QtMocHelpers::PropertyData<bool>(76, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'subsurfaceHandler'
        QtMocHelpers::PropertyData<QObject*>(77, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'output'
        QtMocHelpers::PropertyData<QWaylandOutput*>(78, 0x80000000 | 79, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 11),
        // property 'bufferLocked'
        QtMocHelpers::PropertyData<bool>(80, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'allowDiscardFrontBuffer'
        QtMocHelpers::PropertyData<bool>(81, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QWaylandQuickItem, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN17QWaylandQuickItemE[] = {
    QMetaObject::SuperData::link<QWaylandSurface::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject QWaylandQuickItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QWaylandQuickItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QWaylandQuickItemE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN17QWaylandQuickItemE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17QWaylandQuickItemE_t>.metaTypes,
    nullptr
} };

void QWaylandQuickItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QWaylandQuickItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->surfaceChanged(); break;
        case 1: _t->compositorChanged(); break;
        case 2: _t->paintEnabledChanged(); break;
        case 3: _t->touchEventsEnabledChanged(); break;
        case 4: _t->originChanged(); break;
        case 5: _t->surfaceDestroyed(); break;
        case 6: _t->inputEventsEnabledChanged(); break;
        case 7: _t->focusOnClickChanged(); break;
        case 8: _t->mouseMove((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 9: _t->mouseRelease(); break;
        case 10: _t->subsurfaceHandlerChanged(); break;
        case 11: _t->outputChanged(); break;
        case 12: _t->bufferLockedChanged(); break;
        case 13: _t->allowDiscardFrontBufferChanged(); break;
        case 14: _t->takeFocus((*reinterpret_cast<std::add_pointer_t<QWaylandSeat*>>(_a[1]))); break;
        case 15: _t->takeFocus(); break;
        case 16: _t->setPaintEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->raise(); break;
        case 18: _t->lower(); break;
        case 19: _t->sendMouseMoveEvent((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWaylandSeat*>>(_a[2]))); break;
        case 20: _t->sendMouseMoveEvent((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 21: _t->surfaceMappedChanged(); break;
        case 22: _t->handleSurfaceChanged(); break;
        case 23: _t->handleBufferLockedChanged(); break;
        case 24: _t->parentChanged((*reinterpret_cast<std::add_pointer_t<QWaylandSurface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWaylandSurface*>>(_a[2]))); break;
        case 25: _t->updateSize(); break;
        case 26: _t->updateBuffer((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->updateWindow(); break;
        case 28: _t->updateOutput(); break;
        case 29: _t->beforeSync(); break;
        case 30: _t->handleSubsurfaceAdded((*reinterpret_cast<std::add_pointer_t<QWaylandSurface*>>(_a[1]))); break;
        case 31: _t->handleSubsurfacePosition((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 32: _t->handlePlaceAbove((*reinterpret_cast<std::add_pointer_t<QWaylandSurface*>>(_a[1]))); break;
        case 33: _t->handlePlaceBelow((*reinterpret_cast<std::add_pointer_t<QWaylandSurface*>>(_a[1]))); break;
        case 34: _t->handleDragStarted((*reinterpret_cast<std::add_pointer_t<QWaylandDrag*>>(_a[1]))); break;
        case 35: _t->updateInputMethod((*reinterpret_cast<std::add_pointer_t<Qt::InputMethodQueries>>(_a[1]))); break;
        case 36: _t->updateFocus(); break;
        case 37: { QPointF _r = _t->mapToSurface((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QPointF*>(_a[0]) = std::move(_r); }  break;
        case 38: { QPointF _r = _t->mapFromSurface((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QPointF*>(_a[0]) = std::move(_r); }  break;
        case 39: { QVariant _r = _t->inputMethodQuery((*reinterpret_cast<std::add_pointer_t<Qt::InputMethodQuery>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 40: _t->setPrimary(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWaylandSurface* >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWaylandSurface* >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWaylandSurface* >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWaylandSurface* >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWaylandDrag* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QWaylandQuickItem::*)()>(_a, &QWaylandQuickItem::surfaceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQuickItem::*)()>(_a, &QWaylandQuickItem::compositorChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQuickItem::*)()>(_a, &QWaylandQuickItem::paintEnabledChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQuickItem::*)()>(_a, &QWaylandQuickItem::touchEventsEnabledChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQuickItem::*)()>(_a, &QWaylandQuickItem::originChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQuickItem::*)()>(_a, &QWaylandQuickItem::surfaceDestroyed, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQuickItem::*)()>(_a, &QWaylandQuickItem::inputEventsEnabledChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQuickItem::*)()>(_a, &QWaylandQuickItem::focusOnClickChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQuickItem::*)(const QPointF & )>(_a, &QWaylandQuickItem::mouseMove, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQuickItem::*)()>(_a, &QWaylandQuickItem::mouseRelease, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQuickItem::*)()>(_a, &QWaylandQuickItem::subsurfaceHandlerChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQuickItem::*)()>(_a, &QWaylandQuickItem::outputChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQuickItem::*)()>(_a, &QWaylandQuickItem::bufferLockedChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQuickItem::*)()>(_a, &QWaylandQuickItem::allowDiscardFrontBufferChanged, 13))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWaylandCompositor* >(); break;
        case 8:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWaylandOutput* >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWaylandSurface* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QWaylandCompositor**>(_v) = _t->compositor(); break;
        case 1: *reinterpret_cast<QWaylandSurface**>(_v) = _t->surface(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isPaintEnabled(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->touchEventsEnabled(); break;
        case 4: *reinterpret_cast<QWaylandSurface::Origin*>(_v) = _t->origin(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->inputEventsEnabled(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->focusOnClick(); break;
        case 7: *reinterpret_cast<QObject**>(_v) = _t->subsurfaceHandler(); break;
        case 8: *reinterpret_cast<QWaylandOutput**>(_v) = _t->output(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isBufferLocked(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->allowDiscardFrontBuffer(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setSurface(*reinterpret_cast<QWaylandSurface**>(_v)); break;
        case 2: _t->setPaintEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setTouchEventsEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setInputEventsEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setFocusOnClick(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setSubsurfaceHandler(*reinterpret_cast<QObject**>(_v)); break;
        case 8: _t->setOutput(*reinterpret_cast<QWaylandOutput**>(_v)); break;
        case 9: _t->setBufferLocked(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setAllowDiscardFrontBuffer(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QWaylandQuickItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QWaylandQuickItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QWaylandQuickItemE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int QWaylandQuickItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 41)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 41;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 41)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 41;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void QWaylandQuickItem::surfaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QWaylandQuickItem::compositorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QWaylandQuickItem::paintEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QWaylandQuickItem::touchEventsEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QWaylandQuickItem::originChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QWaylandQuickItem::surfaceDestroyed()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QWaylandQuickItem::inputEventsEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QWaylandQuickItem::focusOnClickChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QWaylandQuickItem::mouseMove(const QPointF & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void QWaylandQuickItem::mouseRelease()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QWaylandQuickItem::subsurfaceHandlerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void QWaylandQuickItem::outputChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void QWaylandQuickItem::bufferLockedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void QWaylandQuickItem::allowDiscardFrontBufferChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}
QT_WARNING_POP
