/****************************************************************************
** Meta object code from reading C++ file 'qwaylandivisurface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtwayland/src/compositor/extensions/qwaylandivisurface.h"
#include "qwaylandsurface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qwaylandivisurface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18QWaylandIviSurfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandIviSurface::qt_create_metaobjectdata<qt_meta_tag_ZN18QWaylandIviSurfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandIviSurface",
        "DefaultProperty",
        "data",
        "surfaceChanged",
        "",
        "iviIdChanged",
        "initialize",
        "QWaylandIviApplication*",
        "iviApplication",
        "QWaylandSurface*",
        "surface",
        "iviId",
        "QWaylandResource",
        "resource",
        "sendConfigure",
        "QSize",
        "size",
        "QQmlListProperty<QObject>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'surfaceChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iviIdChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'initialize'
        QtMocHelpers::MethodData<void(QWaylandIviApplication *, QWaylandSurface *, uint, const QWaylandResource &)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 }, { QMetaType::UInt, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Method 'sendConfigure'
        QtMocHelpers::MethodData<void(const QSize &)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'data'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(2, 0x80000000 | 17, QMC::Readable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag),
        // property 'surface'
        QtMocHelpers::PropertyData<QWaylandSurface*>(10, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'iviId'
        QtMocHelpers::PropertyData<uint>(11, QMetaType::UInt, QMC::DefaultPropertyFlags, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QWaylandIviSurface, qt_meta_tag_ZN18QWaylandIviSurfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QWaylandIviSurface::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandShellSurfaceTemplate<QWaylandIviSurface>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18QWaylandIviSurfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18QWaylandIviSurfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18QWaylandIviSurfaceE_t>.metaTypes,
    nullptr
} };

void QWaylandIviSurface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QWaylandIviSurface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->surfaceChanged(); break;
        case 1: _t->iviIdChanged(); break;
        case 2: _t->initialize((*reinterpret_cast<std::add_pointer_t<QWaylandIviApplication*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWaylandSurface*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QWaylandResource>>(_a[4]))); break;
        case 3: _t->sendConfigure((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QWaylandIviSurface::*)()>(_a, &QWaylandIviSurface::surfaceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandIviSurface::*)()>(_a, &QWaylandIviSurface::iviIdChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->data(); break;
        case 1: *reinterpret_cast<QWaylandSurface**>(_v) = _t->surface(); break;
        case 2: *reinterpret_cast<uint*>(_v) = _t->iviId(); break;
        default: break;
        }
    }
}

const QMetaObject *QWaylandIviSurface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QWaylandIviSurface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18QWaylandIviSurfaceE_t>.strings))
        return static_cast<void*>(this);
    return QWaylandShellSurfaceTemplate<QWaylandIviSurface>::qt_metacast(_clname);
}

int QWaylandIviSurface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandShellSurfaceTemplate<QWaylandIviSurface>::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void QWaylandIviSurface::surfaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QWaylandIviSurface::iviIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
