/****************************************************************************
** Meta object code from reading C++ file 'qwaylandcompositorquickextensions_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtwayland/src/compositor/compositor_api/qwaylandcompositorquickextensions_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qwaylandcompositorquickextensions_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN46QWaylandQuickCompositorQuickExtensionContainerE_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandQuickCompositorQuickExtensionContainer::qt_create_metaobjectdata<qt_meta_tag_ZN46QWaylandQuickCompositorQuickExtensionContainerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandQuickCompositorQuickExtensionContainer",
        "DefaultProperty",
        "data",
        "QML.Element",
        "WaylandCompositor",
        "QML.AddedInVersion",
        "256",
        "extensions",
        "QQmlListProperty<QWaylandCompositorExtension>",
        "QQmlListProperty<QObject>"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'extensions'
        QtMocHelpers::PropertyData<QQmlListProperty<QWaylandCompositorExtension>>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'data'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(2, 0x80000000 | 9, QMC::Readable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QWaylandQuickCompositorQuickExtensionContainer, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QWaylandQuickCompositorQuickExtensionContainer::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandQuickCompositor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN46QWaylandQuickCompositorQuickExtensionContainerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN46QWaylandQuickCompositorQuickExtensionContainerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN46QWaylandQuickCompositorQuickExtensionContainerE_t>.metaTypes,
    nullptr
} };

void QWaylandQuickCompositorQuickExtensionContainer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QWaylandQuickCompositorQuickExtensionContainer *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlListProperty<QWaylandCompositorExtension>*>(_v) = _t->extensions(); break;
        case 1: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->data(); break;
        default: break;
        }
    }
}

const QMetaObject *QWaylandQuickCompositorQuickExtensionContainer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QWaylandQuickCompositorQuickExtensionContainer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN46QWaylandQuickCompositorQuickExtensionContainerE_t>.strings))
        return static_cast<void*>(this);
    return QWaylandQuickCompositor::qt_metacast(_clname);
}

int QWaylandQuickCompositorQuickExtensionContainer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandQuickCompositor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN37QWaylandQtWindowManagerQuickExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandQtWindowManagerQuickExtension::qt_create_metaobjectdata<qt_meta_tag_ZN37QWaylandQtWindowManagerQuickExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandQtWindowManagerQuickExtension",
        "DefaultProperty",
        "data",
        "QML.Element",
        "QtWindowManager",
        "QML.AddedInVersion",
        "256",
        "QQmlListProperty<QObject>"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'data'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(2, 0x80000000 | 7, QMC::Readable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QWaylandQtWindowManagerQuickExtension, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QWaylandQtWindowManagerQuickExtension::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandQtWindowManager::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN37QWaylandQtWindowManagerQuickExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN37QWaylandQtWindowManagerQuickExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN37QWaylandQtWindowManagerQuickExtensionE_t>.metaTypes,
    nullptr
} };

void QWaylandQtWindowManagerQuickExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QWaylandQtWindowManagerQuickExtension *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->data(); break;
        default: break;
        }
    }
}

const QMetaObject *QWaylandQtWindowManagerQuickExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QWaylandQtWindowManagerQuickExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN37QWaylandQtWindowManagerQuickExtensionE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QWaylandQtWindowManager::qt_metacast(_clname);
}

int QWaylandQtWindowManagerQuickExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandQtWindowManager::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN42QWaylandIdleInhibitManagerV1QuickExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandIdleInhibitManagerV1QuickExtension::qt_create_metaobjectdata<qt_meta_tag_ZN42QWaylandIdleInhibitManagerV1QuickExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandIdleInhibitManagerV1QuickExtension",
        "DefaultProperty",
        "data",
        "QML.Element",
        "IdleInhibitManagerV1",
        "QML.AddedInVersion",
        "256",
        "QQmlListProperty<QObject>"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'data'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(2, 0x80000000 | 7, QMC::Readable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QWaylandIdleInhibitManagerV1QuickExtension, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QWaylandIdleInhibitManagerV1QuickExtension::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandIdleInhibitManagerV1::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN42QWaylandIdleInhibitManagerV1QuickExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN42QWaylandIdleInhibitManagerV1QuickExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN42QWaylandIdleInhibitManagerV1QuickExtensionE_t>.metaTypes,
    nullptr
} };

void QWaylandIdleInhibitManagerV1QuickExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QWaylandIdleInhibitManagerV1QuickExtension *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->data(); break;
        default: break;
        }
    }
}

const QMetaObject *QWaylandIdleInhibitManagerV1QuickExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QWaylandIdleInhibitManagerV1QuickExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN42QWaylandIdleInhibitManagerV1QuickExtensionE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QWaylandIdleInhibitManagerV1::qt_metacast(_clname);
}

int QWaylandIdleInhibitManagerV1QuickExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandIdleInhibitManagerV1::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN38QWaylandTextInputManagerQuickExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandTextInputManagerQuickExtension::qt_create_metaobjectdata<qt_meta_tag_ZN38QWaylandTextInputManagerQuickExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandTextInputManagerQuickExtension",
        "DefaultProperty",
        "data",
        "QML.Element",
        "TextInputManager",
        "QML.AddedInVersion",
        "256",
        "QQmlListProperty<QObject>"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'data'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(2, 0x80000000 | 7, QMC::Readable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QWaylandTextInputManagerQuickExtension, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QWaylandTextInputManagerQuickExtension::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandTextInputManager::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN38QWaylandTextInputManagerQuickExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN38QWaylandTextInputManagerQuickExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN38QWaylandTextInputManagerQuickExtensionE_t>.metaTypes,
    nullptr
} };

void QWaylandTextInputManagerQuickExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QWaylandTextInputManagerQuickExtension *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->data(); break;
        default: break;
        }
    }
}

const QMetaObject *QWaylandTextInputManagerQuickExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QWaylandTextInputManagerQuickExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN38QWaylandTextInputManagerQuickExtensionE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QWaylandTextInputManager::qt_metacast(_clname);
}

int QWaylandTextInputManagerQuickExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandTextInputManager::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN40QWaylandTextInputManagerV3QuickExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandTextInputManagerV3QuickExtension::qt_create_metaobjectdata<qt_meta_tag_ZN40QWaylandTextInputManagerV3QuickExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandTextInputManagerV3QuickExtension",
        "DefaultProperty",
        "data",
        "QML.Element",
        "TextInputManagerV3",
        "QML.AddedInVersion",
        "256",
        "QQmlListProperty<QObject>"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'data'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(2, 0x80000000 | 7, QMC::Readable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QWaylandTextInputManagerV3QuickExtension, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QWaylandTextInputManagerV3QuickExtension::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandTextInputManagerV3::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN40QWaylandTextInputManagerV3QuickExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN40QWaylandTextInputManagerV3QuickExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN40QWaylandTextInputManagerV3QuickExtensionE_t>.metaTypes,
    nullptr
} };

void QWaylandTextInputManagerV3QuickExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QWaylandTextInputManagerV3QuickExtension *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->data(); break;
        default: break;
        }
    }
}

const QMetaObject *QWaylandTextInputManagerV3QuickExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QWaylandTextInputManagerV3QuickExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN40QWaylandTextInputManagerV3QuickExtensionE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QWaylandTextInputManagerV3::qt_metacast(_clname);
}

int QWaylandTextInputManagerV3QuickExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandTextInputManagerV3::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN46QWaylandQtTextInputMethodManagerQuickExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandQtTextInputMethodManagerQuickExtension::qt_create_metaobjectdata<qt_meta_tag_ZN46QWaylandQtTextInputMethodManagerQuickExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandQtTextInputMethodManagerQuickExtension",
        "DefaultProperty",
        "data",
        "QML.Element",
        "QtTextInputMethodManager",
        "QML.AddedInVersion",
        "256",
        "QQmlListProperty<QObject>"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'data'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(2, 0x80000000 | 7, QMC::Readable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QWaylandQtTextInputMethodManagerQuickExtension, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QWaylandQtTextInputMethodManagerQuickExtension::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandQtTextInputMethodManager::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN46QWaylandQtTextInputMethodManagerQuickExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN46QWaylandQtTextInputMethodManagerQuickExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN46QWaylandQtTextInputMethodManagerQuickExtensionE_t>.metaTypes,
    nullptr
} };

void QWaylandQtTextInputMethodManagerQuickExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QWaylandQtTextInputMethodManagerQuickExtension *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->data(); break;
        default: break;
        }
    }
}

const QMetaObject *QWaylandQtTextInputMethodManagerQuickExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QWaylandQtTextInputMethodManagerQuickExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN46QWaylandQtTextInputMethodManagerQuickExtensionE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QWaylandQtTextInputMethodManager::qt_metacast(_clname);
}

int QWaylandQtTextInputMethodManagerQuickExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandQtTextInputMethodManager::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
