/****************************************************************************
** Meta object code from reading C++ file 'qwltexturesharingextension_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtwayland/src/compositor/extensions/qwltexturesharingextension_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qwltexturesharingextension_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN31QWaylandTextureSharingExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandTextureSharingExtension::qt_create_metaobjectdata<qt_meta_tag_ZN31QWaylandTextureSharingExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandTextureSharingExtension",
        "bufferResult",
        "",
        "key",
        "QtWayland::ServerBuffer*",
        "buffer",
        "requestBuffer",
        "cleanupBuffers",
        "imageSearchPath"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'bufferResult'
        QtMocHelpers::SignalData<void(const QString &, QtWayland::ServerBuffer *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Slot 'requestBuffer'
        QtMocHelpers::SlotData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'cleanupBuffers'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'imageSearchPath'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::Writable | QMC::Designable | QMC::Scriptable | QMC::Stored | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QWaylandTextureSharingExtension, qt_meta_tag_ZN31QWaylandTextureSharingExtensionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QWaylandTextureSharingExtension::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandCompositorExtensionTemplate<QWaylandTextureSharingExtension>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31QWaylandTextureSharingExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31QWaylandTextureSharingExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN31QWaylandTextureSharingExtensionE_t>.metaTypes,
    nullptr
} };

void QWaylandTextureSharingExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QWaylandTextureSharingExtension *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->bufferResult((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QtWayland::ServerBuffer*>>(_a[2]))); break;
        case 1: _t->requestBuffer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->cleanupBuffers(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QWaylandTextureSharingExtension::*)(const QString & , QtWayland::ServerBuffer * )>(_a, &QWaylandTextureSharingExtension::bufferResult, 0))
            return;
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setImageSearchPath(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QWaylandTextureSharingExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QWaylandTextureSharingExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31QWaylandTextureSharingExtensionE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWaylandServer::zqt_texture_sharing_v1"))
        return static_cast< QtWaylandServer::zqt_texture_sharing_v1*>(this);
    return QWaylandCompositorExtensionTemplate<QWaylandTextureSharingExtension>::qt_metacast(_clname);
}

int QWaylandTextureSharingExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandCompositorExtensionTemplate<QWaylandTextureSharingExtension>::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void QWaylandTextureSharingExtension::bufferResult(const QString & _t1, QtWayland::ServerBuffer * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}
namespace {
struct qt_meta_tag_ZN45QWaylandTextureSharingExtensionQuickExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandTextureSharingExtensionQuickExtension::qt_create_metaobjectdata<qt_meta_tag_ZN45QWaylandTextureSharingExtensionQuickExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandTextureSharingExtensionQuickExtension",
        "DefaultProperty",
        "data",
        "QQmlListProperty<QObject>"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'data'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(2, 0x80000000 | 3, QMC::Readable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QWaylandTextureSharingExtensionQuickExtension, qt_meta_tag_ZN45QWaylandTextureSharingExtensionQuickExtensionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QWaylandTextureSharingExtensionQuickExtension::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandTextureSharingExtension::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN45QWaylandTextureSharingExtensionQuickExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN45QWaylandTextureSharingExtensionQuickExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN45QWaylandTextureSharingExtensionQuickExtensionE_t>.metaTypes,
    nullptr
} };

void QWaylandTextureSharingExtensionQuickExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QWaylandTextureSharingExtensionQuickExtension *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->data(); break;
        default: break;
        }
    }
}

const QMetaObject *QWaylandTextureSharingExtensionQuickExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QWaylandTextureSharingExtensionQuickExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN45QWaylandTextureSharingExtensionQuickExtensionE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QWaylandTextureSharingExtension::qt_metacast(_clname);
}

int QWaylandTextureSharingExtensionQuickExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandTextureSharingExtension::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
