/****************************************************************************
** Meta object code from reading C++ file 'qwaylandqtshellchrome.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../qtwayland/src/imports/compositor-extensions/qtshell/qwaylandqtshellchrome.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qwaylandqtshellchrome.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21QWaylandQtShellChromeE_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandQtShellChrome::qt_create_metaobjectdata<qt_meta_tag_ZN21QWaylandQtShellChromeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandQtShellChrome",
        "QML.Element",
        "QtShellChrome",
        "QML.AddedInVersion",
        "256",
        "currentWindowStateChanged",
        "",
        "currentWindowFlagsChanged",
        "windowMetaInfoChanged",
        "shellSurfaceItemChanged",
        "maximizedRectChanged",
        "titleBarChanged",
        "leftResizeHandleChanged",
        "rightResizeHandleChanged",
        "topResizeHandleChanged",
        "bottomResizeHandleChanged",
        "topLeftResizeHandleChanged",
        "bottomLeftResizeHandleChanged",
        "topRightResizeHandleChanged",
        "bottomRightResizeHandleChanged",
        "activated",
        "deactivated",
        "clientDestroyed",
        "frameMarginChanged",
        "raise",
        "lower",
        "toggleMaximized",
        "toggleMinimized",
        "toggleFullScreen",
        "activate",
        "deactivate",
        "activateOnGrab",
        "QPointingDevice::GrabTransition",
        "transition",
        "updateSurface",
        "updateShellSurface",
        "updateWindowFlags",
        "updateWindowState",
        "updateGeometry",
        "updateDecorations",
        "updateActiveState",
        "updateAutomaticPosition",
        "stopGrab",
        "leftResize",
        "rightResize",
        "topResize",
        "bottomResize",
        "topLeftResize",
        "topRightResize",
        "bottomLeftResize",
        "bottomRightResize",
        "titleBarMove",
        "hasDecorations",
        "windowState",
        "windowFlags",
        "shellSurfaceItem",
        "QWaylandQuickShellSurfaceItem*",
        "maximizedRect",
        "QRect",
        "frameMarginLeft",
        "frameMarginRight",
        "frameMarginTop",
        "frameMarginBottom",
        "titleBar",
        "QQuickItem*",
        "leftResizeHandle",
        "rightResizeHandle",
        "topResizeHandle",
        "bottomResizeHandle",
        "topLeftResizeHandle",
        "topRightResizeHandle",
        "bottomLeftResizeHandle",
        "bottomRightResizeHandle"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentWindowStateChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentWindowFlagsChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'windowMetaInfoChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shellSurfaceItemChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maximizedRectChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titleBarChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'leftResizeHandleChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rightResizeHandleChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'topResizeHandleChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bottomResizeHandleChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'topLeftResizeHandleChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bottomLeftResizeHandleChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'topRightResizeHandleChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bottomRightResizeHandleChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activated'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'deactivated'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clientDestroyed'
        QtMocHelpers::SignalData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'frameMarginChanged'
        QtMocHelpers::SignalData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'raise'
        QtMocHelpers::SlotData<void()>(24, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'lower'
        QtMocHelpers::SlotData<void()>(25, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleMaximized'
        QtMocHelpers::SlotData<void()>(26, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleMinimized'
        QtMocHelpers::SlotData<void()>(27, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleFullScreen'
        QtMocHelpers::SlotData<void()>(28, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'activate'
        QtMocHelpers::SlotData<void()>(29, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'deactivate'
        QtMocHelpers::SlotData<void()>(30, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'activateOnGrab'
        QtMocHelpers::SlotData<void(QPointingDevice::GrabTransition)>(31, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Slot 'updateSurface'
        QtMocHelpers::SlotData<void()>(34, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateShellSurface'
        QtMocHelpers::SlotData<void()>(35, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateWindowFlags'
        QtMocHelpers::SlotData<void()>(36, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateWindowState'
        QtMocHelpers::SlotData<void()>(37, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateGeometry'
        QtMocHelpers::SlotData<void()>(38, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateDecorations'
        QtMocHelpers::SlotData<void()>(39, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateActiveState'
        QtMocHelpers::SlotData<void()>(40, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateAutomaticPosition'
        QtMocHelpers::SlotData<void()>(41, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'stopGrab'
        QtMocHelpers::SlotData<void()>(42, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'leftResize'
        QtMocHelpers::SlotData<void()>(43, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'rightResize'
        QtMocHelpers::SlotData<void()>(44, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'topResize'
        QtMocHelpers::SlotData<void()>(45, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'bottomResize'
        QtMocHelpers::SlotData<void()>(46, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'topLeftResize'
        QtMocHelpers::SlotData<void()>(47, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'topRightResize'
        QtMocHelpers::SlotData<void()>(48, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'bottomLeftResize'
        QtMocHelpers::SlotData<void()>(49, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'bottomRightResize'
        QtMocHelpers::SlotData<void()>(50, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'titleBarMove'
        QtMocHelpers::SlotData<void()>(51, 6, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'hasDecorations'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'windowState'
        QtMocHelpers::PropertyData<uint>(53, QMetaType::UInt, QMC::DefaultPropertyFlags, 0),
        // property 'windowFlags'
        QtMocHelpers::PropertyData<uint>(54, QMetaType::UInt, QMC::DefaultPropertyFlags, 1),
        // property 'shellSurfaceItem'
        QtMocHelpers::PropertyData<QWaylandQuickShellSurfaceItem*>(55, 0x80000000 | 56, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'maximizedRect'
        QtMocHelpers::PropertyData<QRect>(57, 0x80000000 | 58, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'frameMarginLeft'
        QtMocHelpers::PropertyData<int>(59, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'frameMarginRight'
        QtMocHelpers::PropertyData<int>(60, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'frameMarginTop'
        QtMocHelpers::PropertyData<int>(61, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'frameMarginBottom'
        QtMocHelpers::PropertyData<int>(62, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'titleBar'
        QtMocHelpers::PropertyData<QQuickItem*>(63, 0x80000000 | 64, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'leftResizeHandle'
        QtMocHelpers::PropertyData<QQuickItem*>(65, 0x80000000 | 64, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'rightResizeHandle'
        QtMocHelpers::PropertyData<QQuickItem*>(66, 0x80000000 | 64, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'topResizeHandle'
        QtMocHelpers::PropertyData<QQuickItem*>(67, 0x80000000 | 64, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8),
        // property 'bottomResizeHandle'
        QtMocHelpers::PropertyData<QQuickItem*>(68, 0x80000000 | 64, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 9),
        // property 'topLeftResizeHandle'
        QtMocHelpers::PropertyData<QQuickItem*>(69, 0x80000000 | 64, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 10),
        // property 'topRightResizeHandle'
        QtMocHelpers::PropertyData<QQuickItem*>(70, 0x80000000 | 64, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 12),
        // property 'bottomLeftResizeHandle'
        QtMocHelpers::PropertyData<QQuickItem*>(71, 0x80000000 | 64, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 11),
        // property 'bottomRightResizeHandle'
        QtMocHelpers::PropertyData<QQuickItem*>(72, 0x80000000 | 64, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 13),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QWaylandQtShellChrome, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QWaylandQtShellChrome::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QWaylandQtShellChromeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QWaylandQtShellChromeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21QWaylandQtShellChromeE_t>.metaTypes,
    nullptr
} };

void QWaylandQtShellChrome::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QWaylandQtShellChrome *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentWindowStateChanged(); break;
        case 1: _t->currentWindowFlagsChanged(); break;
        case 2: _t->windowMetaInfoChanged(); break;
        case 3: _t->shellSurfaceItemChanged(); break;
        case 4: _t->maximizedRectChanged(); break;
        case 5: _t->titleBarChanged(); break;
        case 6: _t->leftResizeHandleChanged(); break;
        case 7: _t->rightResizeHandleChanged(); break;
        case 8: _t->topResizeHandleChanged(); break;
        case 9: _t->bottomResizeHandleChanged(); break;
        case 10: _t->topLeftResizeHandleChanged(); break;
        case 11: _t->bottomLeftResizeHandleChanged(); break;
        case 12: _t->topRightResizeHandleChanged(); break;
        case 13: _t->bottomRightResizeHandleChanged(); break;
        case 14: _t->activated(); break;
        case 15: _t->deactivated(); break;
        case 16: _t->clientDestroyed(); break;
        case 17: _t->frameMarginChanged(); break;
        case 18: _t->raise(); break;
        case 19: _t->lower(); break;
        case 20: _t->toggleMaximized(); break;
        case 21: _t->toggleMinimized(); break;
        case 22: _t->toggleFullScreen(); break;
        case 23: _t->activate(); break;
        case 24: _t->deactivate(); break;
        case 25: _t->activateOnGrab((*reinterpret_cast<std::add_pointer_t<QPointingDevice::GrabTransition>>(_a[1]))); break;
        case 26: _t->updateSurface(); break;
        case 27: _t->updateShellSurface(); break;
        case 28: _t->updateWindowFlags(); break;
        case 29: _t->updateWindowState(); break;
        case 30: _t->updateGeometry(); break;
        case 31: _t->updateDecorations(); break;
        case 32: _t->updateActiveState(); break;
        case 33: _t->updateAutomaticPosition(); break;
        case 34: _t->stopGrab(); break;
        case 35: _t->leftResize(); break;
        case 36: _t->rightResize(); break;
        case 37: _t->topResize(); break;
        case 38: _t->bottomResize(); break;
        case 39: _t->topLeftResize(); break;
        case 40: _t->topRightResize(); break;
        case 41: _t->bottomLeftResize(); break;
        case 42: _t->bottomRightResize(); break;
        case 43: _t->titleBarMove(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellChrome::*)()>(_a, &QWaylandQtShellChrome::currentWindowStateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellChrome::*)()>(_a, &QWaylandQtShellChrome::currentWindowFlagsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellChrome::*)()>(_a, &QWaylandQtShellChrome::windowMetaInfoChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellChrome::*)()>(_a, &QWaylandQtShellChrome::shellSurfaceItemChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellChrome::*)()>(_a, &QWaylandQtShellChrome::maximizedRectChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellChrome::*)()>(_a, &QWaylandQtShellChrome::titleBarChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellChrome::*)()>(_a, &QWaylandQtShellChrome::leftResizeHandleChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellChrome::*)()>(_a, &QWaylandQtShellChrome::rightResizeHandleChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellChrome::*)()>(_a, &QWaylandQtShellChrome::topResizeHandleChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellChrome::*)()>(_a, &QWaylandQtShellChrome::bottomResizeHandleChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellChrome::*)()>(_a, &QWaylandQtShellChrome::topLeftResizeHandleChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellChrome::*)()>(_a, &QWaylandQtShellChrome::bottomLeftResizeHandleChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellChrome::*)()>(_a, &QWaylandQtShellChrome::topRightResizeHandleChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellChrome::*)()>(_a, &QWaylandQtShellChrome::bottomRightResizeHandleChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellChrome::*)()>(_a, &QWaylandQtShellChrome::activated, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellChrome::*)()>(_a, &QWaylandQtShellChrome::deactivated, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellChrome::*)()>(_a, &QWaylandQtShellChrome::clientDestroyed, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellChrome::*)()>(_a, &QWaylandQtShellChrome::frameMarginChanged, 17))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 17:
        case 16:
        case 15:
        case 14:
        case 13:
        case 12:
        case 11:
        case 10:
        case 9:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWaylandQuickShellSurfaceItem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->hasDecorations(); break;
        case 1: *reinterpret_cast<uint*>(_v) = _t->currentWindowState(); break;
        case 2: *reinterpret_cast<uint*>(_v) = _t->currentWindowFlags(); break;
        case 3: *reinterpret_cast<QWaylandQuickShellSurfaceItem**>(_v) = _t->shellSurfaceItem(); break;
        case 4: *reinterpret_cast<QRect*>(_v) = _t->maximizedRect(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->frameMarginLeft(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->frameMarginRight(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->frameMarginTop(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->frameMarginBottom(); break;
        case 9: *reinterpret_cast<QQuickItem**>(_v) = _t->titleBar(); break;
        case 10: *reinterpret_cast<QQuickItem**>(_v) = _t->leftResizeHandle(); break;
        case 11: *reinterpret_cast<QQuickItem**>(_v) = _t->rightResizeHandle(); break;
        case 12: *reinterpret_cast<QQuickItem**>(_v) = _t->topResizeHandle(); break;
        case 13: *reinterpret_cast<QQuickItem**>(_v) = _t->bottomResizeHandle(); break;
        case 14: *reinterpret_cast<QQuickItem**>(_v) = _t->topLeftResizeHandle(); break;
        case 15: *reinterpret_cast<QQuickItem**>(_v) = _t->topRightResizeHandle(); break;
        case 16: *reinterpret_cast<QQuickItem**>(_v) = _t->bottomLeftResizeHandle(); break;
        case 17: *reinterpret_cast<QQuickItem**>(_v) = _t->bottomRightResizeHandle(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 3: _t->setShellSurfaceItem(*reinterpret_cast<QWaylandQuickShellSurfaceItem**>(_v)); break;
        case 4: _t->setMaximizedRect(*reinterpret_cast<QRect*>(_v)); break;
        case 5: _t->setFrameMarginLeft(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setFrameMarginRight(*reinterpret_cast<int*>(_v)); break;
        case 7: _t->setFrameMarginTop(*reinterpret_cast<int*>(_v)); break;
        case 8: _t->setFrameMarginBottom(*reinterpret_cast<int*>(_v)); break;
        case 9: _t->setTitleBar(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 10: _t->setLeftResizeHandle(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 11: _t->setRightResizeHandle(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 12: _t->setTopResizeHandle(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 13: _t->setBottomResizeHandle(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 14: _t->setTopLeftResizeHandle(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 15: _t->setTopRightResizeHandle(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 16: _t->setBottomLeftResizeHandle(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 17: _t->setBottomRightResizeHandle(*reinterpret_cast<QQuickItem**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QWaylandQtShellChrome::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QWaylandQtShellChrome::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QWaylandQtShellChromeE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int QWaylandQtShellChrome::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 44)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 44;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void QWaylandQtShellChrome::currentWindowStateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QWaylandQtShellChrome::currentWindowFlagsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QWaylandQtShellChrome::windowMetaInfoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QWaylandQtShellChrome::shellSurfaceItemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QWaylandQtShellChrome::maximizedRectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QWaylandQtShellChrome::titleBarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QWaylandQtShellChrome::leftResizeHandleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QWaylandQtShellChrome::rightResizeHandleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QWaylandQtShellChrome::topResizeHandleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QWaylandQtShellChrome::bottomResizeHandleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QWaylandQtShellChrome::topLeftResizeHandleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void QWaylandQtShellChrome::bottomLeftResizeHandleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void QWaylandQtShellChrome::topRightResizeHandleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void QWaylandQtShellChrome::bottomRightResizeHandleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void QWaylandQtShellChrome::activated()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void QWaylandQtShellChrome::deactivated()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void QWaylandQtShellChrome::clientDestroyed()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void QWaylandQtShellChrome::frameMarginChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}
QT_WARNING_POP
