/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<private/qwaylandcompositorxdgshell_p.h>)
#  include <private/qwaylandcompositorxdgshell_p.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_QtWayland_Compositor_XdgShell()
{
    qmlRegisterModule("QtWayland.Compositor.XdgShell", 1, 0);
    qmlRegisterModule("QtWayland.Compositor.XdgShell", 1, 254);
    qmlRegisterModule("QtWayland.Compositor.XdgShell", 6, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<QWaylandQuickXdgOutputV1Foreign>("QtWayland.Compositor.XdgShell", 6);
    QMetaType::fromType<QWaylandQuickXdgOutputV1Foreign *>().id();
    QMetaType::fromType<QWaylandXdgDecorationManagerV1 *>().id();
    qmlRegisterTypesAndRevisions<QWaylandXdgDecorationManagerV1QuickExtension>("QtWayland.Compositor.XdgShell", 6);
    QMetaType::fromType<QWaylandXdgOutputManagerV1 *>().id();
    qmlRegisterTypesAndRevisions<QWaylandXdgOutputManagerV1QuickExtension>("QtWayland.Compositor.XdgShell", 6);
    QMetaType::fromType<QWaylandXdgOutputV1 *>().id();
    qmlRegisterTypesAndRevisions<QWaylandXdgPopupForeign>("QtWayland.Compositor.XdgShell", 6);
    QMetaType::fromType<QWaylandXdgPopupForeign *>().id();
    QMetaType::fromType<QWaylandXdgShell *>().id();
    qmlRegisterTypesAndRevisions<QWaylandXdgShellQuickExtension>("QtWayland.Compositor.XdgShell", 6);
    qmlRegisterTypesAndRevisions<QWaylandXdgSurfaceForeign>("QtWayland.Compositor.XdgShell", 6);
    QMetaType::fromType<QWaylandXdgSurfaceForeign *>().id();
    qmlRegisterTypesAndRevisions<QWaylandXdgTopLevelForeign>("QtWayland.Compositor.XdgShell", 6);
    QMetaType::fromType<QWaylandXdgTopLevelForeign *>().id();
    qmlRegisterEnum<QWaylandXdgToplevel::State>("QWaylandXdgToplevel::State");
    qmlRegisterEnum<QWaylandXdgToplevel::DecorationMode>("QWaylandXdgToplevel::DecorationMode");
    QT_WARNING_POP
    qmlRegisterModule("QtWayland.Compositor.XdgShell", 6, 12);
}

static const QQmlModuleRegistration qtWaylandCompositorXdgShellRegistration("QtWayland.Compositor.XdgShell", qml_register_types_QtWayland_Compositor_XdgShell);
