/* Generated by wayland-scanner 1.26.0 */

/*
 * Copyright (C) 2015 The Qt Company Ltd.
 * SPDX-License-Identifier: LicenseRef-Qt-Commercial OR BSD-3-Clause
 */

#include <stdbool.h>
#include <stdlib.h>
#include <stdint.h>
#include "wayland-util.h"

#ifndef __has_attribute
# define __has_attribute(x) 0  /* Compatibility with non-clang compilers. */
#endif

#if (__has_attribute(visibility) || defined(__GNUC__) && __GNUC__ >= 4)
#define WL_PRIVATE __attribute__ ((visibility("hidden")))
#else
#define WL_PRIVATE
#endif


static const struct wl_interface *qt_windowmanager_types[] = {
	NULL,
	NULL,
};

static const struct wl_message qt_windowmanager_requests[] = {
	{ "open_url", "us", qt_windowmanager_types + 0 },
};

static const struct wl_message qt_windowmanager_events[] = {
	{ "hints", "i", qt_windowmanager_types + 0 },
	{ "quit", "", qt_windowmanager_types + 0 },
};

WL_PRIVATE const struct wl_interface qt_windowmanager_interface = {
	"qt_windowmanager", 1,
	1, qt_windowmanager_requests,
	2, qt_windowmanager_events,
};

