/****************************************************************************
** Meta object code from reading C++ file 'qwaylandoutput.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtwayland/src/compositor/compositor_api/qwaylandoutput.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qwaylandoutput.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14QWaylandOutputE_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandOutput::qt_create_metaobjectdata<qt_meta_tag_ZN14QWaylandOutputE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandOutput",
        "QML.Element",
        "WaylandOutputBase",
        "QML.AddedInVersion",
        "256",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Cannot create instance of WaylandOutputBase, use WaylandOutput ins"
        "tead",
        "compositorChanged",
        "",
        "windowChanged",
        "positionChanged",
        "geometryChanged",
        "modeAdded",
        "currentModeChanged",
        "availableGeometryChanged",
        "physicalSizeChanged",
        "scaleFactorChanged",
        "subpixelChanged",
        "transformChanged",
        "sizeFollowsWindowChanged",
        "physicalSizeFollowsSizeChanged",
        "manufacturerChanged",
        "modelChanged",
        "windowDestroyed",
        "_q_handleMaybeWindowPixelSizeChanged",
        "_q_handleWindowDestroyed",
        "compositor",
        "QWaylandCompositor*",
        "window",
        "QWindow*",
        "manufacturer",
        "model",
        "position",
        "QPoint",
        "geometry",
        "QRect",
        "availableGeometry",
        "physicalSize",
        "QSize",
        "subpixel",
        "QWaylandOutput::Subpixel",
        "transform",
        "QWaylandOutput::Transform",
        "scaleFactor",
        "sizeFollowsWindow",
        "Subpixel",
        "SubpixelUnknown",
        "SubpixelNone",
        "SubpixelHorizontalRgb",
        "SubpixelHorizontalBgr",
        "SubpixelVerticalRgb",
        "SubpixelVerticalBgr",
        "Transform",
        "TransformNormal",
        "Transform90",
        "Transform180",
        "Transform270",
        "TransformFlipped",
        "TransformFlipped90",
        "TransformFlipped180",
        "TransformFlipped270"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'compositorChanged'
        QtMocHelpers::SignalData<void()>(9, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'windowChanged'
        QtMocHelpers::SignalData<void()>(11, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void()>(12, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'geometryChanged'
        QtMocHelpers::SignalData<void()>(13, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modeAdded'
        QtMocHelpers::SignalData<void()>(14, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentModeChanged'
        QtMocHelpers::SignalData<void()>(15, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'availableGeometryChanged'
        QtMocHelpers::SignalData<void()>(16, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'physicalSizeChanged'
        QtMocHelpers::SignalData<void()>(17, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scaleFactorChanged'
        QtMocHelpers::SignalData<void()>(18, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'subpixelChanged'
        QtMocHelpers::SignalData<void()>(19, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transformChanged'
        QtMocHelpers::SignalData<void()>(20, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sizeFollowsWindowChanged'
        QtMocHelpers::SignalData<void()>(21, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'physicalSizeFollowsSizeChanged'
        QtMocHelpers::SignalData<void()>(22, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'manufacturerChanged'
        QtMocHelpers::SignalData<void()>(23, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modelChanged'
        QtMocHelpers::SignalData<void()>(24, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'windowDestroyed'
        QtMocHelpers::SignalData<void()>(25, 10, QMC::AccessPublic, QMetaType::Void),
        // Slot '_q_handleMaybeWindowPixelSizeChanged'
        QtMocHelpers::SlotData<void()>(26, 10, QMC::AccessPrivate, QMetaType::Void),
        // Slot '_q_handleWindowDestroyed'
        QtMocHelpers::SlotData<void()>(27, 10, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'compositor'
        QtMocHelpers::PropertyData<QWaylandCompositor*>(28, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'window'
        QtMocHelpers::PropertyData<QWindow*>(30, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'manufacturer'
        QtMocHelpers::PropertyData<QString>(32, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'model'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'position'
        QtMocHelpers::PropertyData<QPoint>(34, 0x80000000 | 35, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'geometry'
        QtMocHelpers::PropertyData<QRect>(36, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'availableGeometry'
        QtMocHelpers::PropertyData<QRect>(38, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'physicalSize'
        QtMocHelpers::PropertyData<QSize>(39, 0x80000000 | 40, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'subpixel'
        QtMocHelpers::PropertyData<QWaylandOutput::Subpixel>(41, 0x80000000 | 42, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 9),
        // property 'transform'
        QtMocHelpers::PropertyData<QWaylandOutput::Transform>(43, 0x80000000 | 44, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 10),
        // property 'scaleFactor'
        QtMocHelpers::PropertyData<int>(45, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'sizeFollowsWindow'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Subpixel'
        QtMocHelpers::EnumData<enum Subpixel>(47, 47, QMC::EnumFlags{}).add({
            {   48, Subpixel::SubpixelUnknown },
            {   49, Subpixel::SubpixelNone },
            {   50, Subpixel::SubpixelHorizontalRgb },
            {   51, Subpixel::SubpixelHorizontalBgr },
            {   52, Subpixel::SubpixelVerticalRgb },
            {   53, Subpixel::SubpixelVerticalBgr },
        }),
        // enum 'Transform'
        QtMocHelpers::EnumData<enum Transform>(54, 54, QMC::EnumFlags{}).add({
            {   55, Transform::TransformNormal },
            {   56, Transform::Transform90 },
            {   57, Transform::Transform180 },
            {   58, Transform::Transform270 },
            {   59, Transform::TransformFlipped },
            {   60, Transform::TransformFlipped90 },
            {   61, Transform::TransformFlipped180 },
            {   62, Transform::TransformFlipped270 },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<QWaylandOutput, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QWaylandOutput::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14QWaylandOutputE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14QWaylandOutputE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14QWaylandOutputE_t>.metaTypes,
    nullptr
} };

void QWaylandOutput::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QWaylandOutput *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->compositorChanged(); break;
        case 1: _t->windowChanged(); break;
        case 2: _t->positionChanged(); break;
        case 3: _t->geometryChanged(); break;
        case 4: _t->modeAdded(); break;
        case 5: _t->currentModeChanged(); break;
        case 6: _t->availableGeometryChanged(); break;
        case 7: _t->physicalSizeChanged(); break;
        case 8: _t->scaleFactorChanged(); break;
        case 9: _t->subpixelChanged(); break;
        case 10: _t->transformChanged(); break;
        case 11: _t->sizeFollowsWindowChanged(); break;
        case 12: _t->physicalSizeFollowsSizeChanged(); break;
        case 13: _t->manufacturerChanged(); break;
        case 14: _t->modelChanged(); break;
        case 15: _t->windowDestroyed(); break;
        case 16: _t->d_func()->_q_handleMaybeWindowPixelSizeChanged(); break;
        case 17: _t->d_func()->_q_handleWindowDestroyed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QWaylandOutput::*)()>(_a, &QWaylandOutput::compositorChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandOutput::*)()>(_a, &QWaylandOutput::windowChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandOutput::*)()>(_a, &QWaylandOutput::positionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandOutput::*)()>(_a, &QWaylandOutput::geometryChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandOutput::*)()>(_a, &QWaylandOutput::modeAdded, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandOutput::*)()>(_a, &QWaylandOutput::currentModeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandOutput::*)()>(_a, &QWaylandOutput::availableGeometryChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandOutput::*)()>(_a, &QWaylandOutput::physicalSizeChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandOutput::*)()>(_a, &QWaylandOutput::scaleFactorChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandOutput::*)()>(_a, &QWaylandOutput::subpixelChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandOutput::*)()>(_a, &QWaylandOutput::transformChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandOutput::*)()>(_a, &QWaylandOutput::sizeFollowsWindowChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandOutput::*)()>(_a, &QWaylandOutput::physicalSizeFollowsSizeChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandOutput::*)()>(_a, &QWaylandOutput::manufacturerChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandOutput::*)()>(_a, &QWaylandOutput::modelChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandOutput::*)()>(_a, &QWaylandOutput::windowDestroyed, 15))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QWaylandCompositor**>(_v) = _t->compositor(); break;
        case 1: *reinterpret_cast<QWindow**>(_v) = _t->window(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->manufacturer(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->model(); break;
        case 4: *reinterpret_cast<QPoint*>(_v) = _t->position(); break;
        case 5: *reinterpret_cast<QRect*>(_v) = _t->geometry(); break;
        case 6: *reinterpret_cast<QRect*>(_v) = _t->availableGeometry(); break;
        case 7: *reinterpret_cast<QSize*>(_v) = _t->physicalSize(); break;
        case 8: *reinterpret_cast<QWaylandOutput::Subpixel*>(_v) = _t->subpixel(); break;
        case 9: *reinterpret_cast<QWaylandOutput::Transform*>(_v) = _t->transform(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->scaleFactor(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->sizeFollowsWindow(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCompositor(*reinterpret_cast<QWaylandCompositor**>(_v)); break;
        case 1: _t->setWindow(*reinterpret_cast<QWindow**>(_v)); break;
        case 2: _t->setManufacturer(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setModel(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setPosition(*reinterpret_cast<QPoint*>(_v)); break;
        case 6: _t->setAvailableGeometry(*reinterpret_cast<QRect*>(_v)); break;
        case 7: _t->setPhysicalSize(*reinterpret_cast<QSize*>(_v)); break;
        case 8: _t->setSubpixel(*reinterpret_cast<QWaylandOutput::Subpixel*>(_v)); break;
        case 9: _t->setTransform(*reinterpret_cast<QWaylandOutput::Transform*>(_v)); break;
        case 10: _t->setScaleFactor(*reinterpret_cast<int*>(_v)); break;
        case 11: _t->setSizeFollowsWindow(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QWaylandOutput::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QWaylandOutput::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14QWaylandOutputE_t>.strings))
        return static_cast<void*>(this);
    return QWaylandObject::qt_metacast(_clname);
}

int QWaylandOutput::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void QWaylandOutput::compositorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QWaylandOutput::windowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QWaylandOutput::positionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QWaylandOutput::geometryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QWaylandOutput::modeAdded()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QWaylandOutput::currentModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QWaylandOutput::availableGeometryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QWaylandOutput::physicalSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QWaylandOutput::scaleFactorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QWaylandOutput::subpixelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QWaylandOutput::transformChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void QWaylandOutput::sizeFollowsWindowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void QWaylandOutput::physicalSizeFollowsSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void QWaylandOutput::manufacturerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void QWaylandOutput::modelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void QWaylandOutput::windowDestroyed()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}
QT_WARNING_POP
