/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<private/qwaylandcompositorquickextensions_p.h>)
#  include <private/qwaylandcompositorquickextensions_p.h>
#endif
#if __has_include(<private/qwaylandmousetracker_p.h>)
#  include <private/qwaylandmousetracker_p.h>
#endif
#if __has_include(<private/qwaylandquickhardwarelayer_p.h>)
#  include <private/qwaylandquickhardwarelayer_p.h>
#endif
#if __has_include(<qwaylandclient.h>)
#  include <qwaylandclient.h>
#endif
#if __has_include(<qwaylandcompositor.h>)
#  include <qwaylandcompositor.h>
#endif
#if __has_include(<qwaylandcompositorextension.h>)
#  include <qwaylandcompositorextension.h>
#endif
#if __has_include(<qwaylanddrag.h>)
#  include <qwaylanddrag.h>
#endif
#if __has_include(<qwaylandkeymap.h>)
#  include <qwaylandkeymap.h>
#endif
#if __has_include(<qwaylandoutput.h>)
#  include <qwaylandoutput.h>
#endif
#if __has_include(<qwaylandquickitem.h>)
#  include <qwaylandquickitem.h>
#endif
#if __has_include(<qwaylandquickoutput.h>)
#  include <qwaylandquickoutput.h>
#endif
#if __has_include(<qwaylandquickshellsurfaceitem.h>)
#  include <qwaylandquickshellsurfaceitem.h>
#endif
#if __has_include(<qwaylandquicksurface.h>)
#  include <qwaylandquicksurface.h>
#endif
#if __has_include(<qwaylandresource.h>)
#  include <qwaylandresource.h>
#endif
#if __has_include(<qwaylandseat.h>)
#  include <qwaylandseat.h>
#endif
#if __has_include(<qwaylandshell.h>)
#  include <qwaylandshell.h>
#endif
#if __has_include(<qwaylandshellsurface.h>)
#  include <qwaylandshellsurface.h>
#endif
#if __has_include(<qwaylandsurface.h>)
#  include <qwaylandsurface.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_QtWayland_Compositor()
{
    qmlRegisterModule("QtWayland.Compositor", 1, 0);
    qmlRegisterModule("QtWayland.Compositor", 1, 254);
    qmlRegisterModule("QtWayland.Compositor", 6, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<QWaylandClient>("QtWayland.Compositor", 6);
    qmlRegisterTypesAndRevisions<QWaylandCompositor>("QtWayland.Compositor", 6);
    qmlRegisterEnum<QWaylandCompositor::ShmFormat>("QWaylandCompositor::ShmFormat");
    qmlRegisterTypesAndRevisions<QWaylandCompositorExtension>("QtWayland.Compositor", 6);
    qmlRegisterTypesAndRevisions<QWaylandDrag>("QtWayland.Compositor", 6);
    QMetaType::fromType<QWaylandIdleInhibitManagerV1 *>().id();
    qmlRegisterTypesAndRevisions<QWaylandIdleInhibitManagerV1QuickExtension>("QtWayland.Compositor", 6);
    qmlRegisterTypesAndRevisions<QWaylandKeymap>("QtWayland.Compositor", 6);
    qmlRegisterTypesAndRevisions<QWaylandMouseTracker>("QtWayland.Compositor", 6);
    qmlRegisterAnonymousTypesAndRevisions<QQuickItem>("QtWayland.Compositor", 6);
    QMetaType::fromType<QWaylandObject *>().id();
    qmlRegisterTypesAndRevisions<QWaylandOutput>("QtWayland.Compositor", 6);
    qmlRegisterEnum<QWaylandOutput::Subpixel>("QWaylandOutput::Subpixel");
    qmlRegisterEnum<QWaylandOutput::Transform>("QWaylandOutput::Transform");
    QMetaType::fromType<QWaylandQtTextInputMethodManager *>().id();
    qmlRegisterTypesAndRevisions<QWaylandQtTextInputMethodManagerQuickExtension>("QtWayland.Compositor", 6);
    QMetaType::fromType<QWaylandQtWindowManager *>().id();
    qmlRegisterTypesAndRevisions<QWaylandQtWindowManagerQuickExtension>("QtWayland.Compositor", 6);
    QMetaType::fromType<QWaylandQuickCompositor *>().id();
    qmlRegisterTypesAndRevisions<QWaylandQuickCompositorQuickExtensionContainer>("QtWayland.Compositor", 6);
    qmlRegisterTypesAndRevisions<QWaylandQuickHardwareLayer>("QtWayland.Compositor", 6);
    qmlRegisterTypesAndRevisions<QWaylandQuickItem>("QtWayland.Compositor", 6);
    qmlRegisterTypesAndRevisions<QWaylandQuickOutput>("QtWayland.Compositor", 6);
    qmlRegisterTypesAndRevisions<QWaylandQuickShellSurfaceItem>("QtWayland.Compositor", 6);
    qmlRegisterTypesAndRevisions<QWaylandQuickSurface>("QtWayland.Compositor", 6);
    qmlRegisterTypesAndRevisions<QWaylandResource>("QtWayland.Compositor", 6);
    QMetaType::fromType<QWaylandResource *>().id();
    qmlRegisterTypesAndRevisions<QWaylandSeat>("QtWayland.Compositor", 6);
    qmlRegisterEnum<QWaylandSeat::CapabilityFlags>("QWaylandSeat::CapabilityFlags");
    qmlRegisterEnum<QWaylandSeat::CapabilityFlag>("QWaylandSeat::CapabilityFlag");
    qmlRegisterTypesAndRevisions<QWaylandShell>("QtWayland.Compositor", 6);
    qmlRegisterEnum<QWaylandShell::FocusPolicy>("QWaylandShell::FocusPolicy");
    qmlRegisterTypesAndRevisions<QWaylandShellSurface>("QtWayland.Compositor", 6);
    qmlRegisterTypesAndRevisions<QWaylandSurface>("QtWayland.Compositor", 6);
    qmlRegisterEnum<QWaylandSurface::Origin>("QWaylandSurface::Origin");
    QMetaType::fromType<QWaylandTextInputManager *>().id();
    qmlRegisterTypesAndRevisions<QWaylandTextInputManagerQuickExtension>("QtWayland.Compositor", 6);
    QMetaType::fromType<QWaylandTextInputManagerV3 *>().id();
    qmlRegisterTypesAndRevisions<QWaylandTextInputManagerV3QuickExtension>("QtWayland.Compositor", 6);
    QT_WARNING_POP
    qmlRegisterModule("QtWayland.Compositor", 6, 12);
}

static const QQmlModuleRegistration qtWaylandCompositorRegistration("QtWayland.Compositor", qml_register_types_QtWayland_Compositor);
