/****************************************************************************
** Meta object code from reading C++ file 'qwaylandview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtwayland/src/compositor/compositor_api/qwaylandview.h"
#include "qwaylandoutput.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qwaylandview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12QWaylandViewE_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandView::qt_create_metaobjectdata<qt_meta_tag_ZN12QWaylandViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandView",
        "surfaceChanged",
        "",
        "surfaceDestroyed",
        "outputChanged",
        "bufferLockedChanged",
        "allowDiscardFrontBufferChanged",
        "renderObject",
        "surface",
        "QWaylandSurface*",
        "output",
        "QWaylandOutput*",
        "bufferLocked",
        "allowDiscardFrontBuffer"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'surfaceChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'surfaceDestroyed'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bufferLockedChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'allowDiscardFrontBufferChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'renderObject'
        QtMocHelpers::PropertyData<QObject*>(7, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'surface'
        QtMocHelpers::PropertyData<QWaylandSurface*>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'output'
        QtMocHelpers::PropertyData<QWaylandOutput*>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'bufferLocked'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'allowDiscardFrontBuffer'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QWaylandView, qt_meta_tag_ZN12QWaylandViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QWaylandView::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12QWaylandViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12QWaylandViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12QWaylandViewE_t>.metaTypes,
    nullptr
} };

void QWaylandView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QWaylandView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->surfaceChanged(); break;
        case 1: _t->surfaceDestroyed(); break;
        case 2: _t->outputChanged(); break;
        case 3: _t->bufferLockedChanged(); break;
        case 4: _t->allowDiscardFrontBufferChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QWaylandView::*)()>(_a, &QWaylandView::surfaceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandView::*)()>(_a, &QWaylandView::surfaceDestroyed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandView::*)()>(_a, &QWaylandView::outputChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandView::*)()>(_a, &QWaylandView::bufferLockedChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandView::*)()>(_a, &QWaylandView::allowDiscardFrontBufferChanged, 4))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWaylandOutput* >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWaylandSurface* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QObject**>(_v) = _t->renderObject(); break;
        case 1: *reinterpret_cast<QWaylandSurface**>(_v) = _t->surface(); break;
        case 2: *reinterpret_cast<QWaylandOutput**>(_v) = _t->output(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isBufferLocked(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->allowDiscardFrontBuffer(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setSurface(*reinterpret_cast<QWaylandSurface**>(_v)); break;
        case 2: _t->setOutput(*reinterpret_cast<QWaylandOutput**>(_v)); break;
        case 3: _t->setBufferLocked(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setAllowDiscardFrontBuffer(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QWaylandView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QWaylandView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12QWaylandViewE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QWaylandView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void QWaylandView::surfaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QWaylandView::surfaceDestroyed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QWaylandView::outputChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QWaylandView::bufferLockedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QWaylandView::allowDiscardFrontBufferChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
