/****************************************************************************
** Meta object code from reading C++ file 'qwaylandxdgoutputv1.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtwayland/src/compositor/extensions/qwaylandxdgoutputv1.h"
#include "qwaylandoutput.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qwaylandxdgoutputv1.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN26QWaylandXdgOutputManagerV1E_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandXdgOutputManagerV1::qt_create_metaobjectdata<qt_meta_tag_ZN26QWaylandXdgOutputManagerV1E_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandXdgOutputManagerV1"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QWaylandXdgOutputManagerV1, qt_meta_tag_ZN26QWaylandXdgOutputManagerV1E_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QWaylandXdgOutputManagerV1::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandCompositorExtensionTemplate<QWaylandXdgOutputManagerV1>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26QWaylandXdgOutputManagerV1E_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26QWaylandXdgOutputManagerV1E_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26QWaylandXdgOutputManagerV1E_t>.metaTypes,
    nullptr
} };

void QWaylandXdgOutputManagerV1::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QWaylandXdgOutputManagerV1 *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *QWaylandXdgOutputManagerV1::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QWaylandXdgOutputManagerV1::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26QWaylandXdgOutputManagerV1E_t>.strings))
        return static_cast<void*>(this);
    return QWaylandCompositorExtensionTemplate<QWaylandXdgOutputManagerV1>::qt_metacast(_clname);
}

int QWaylandXdgOutputManagerV1::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandCompositorExtensionTemplate<QWaylandXdgOutputManagerV1>::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN19QWaylandXdgOutputV1E_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandXdgOutputV1::qt_create_metaobjectdata<qt_meta_tag_ZN19QWaylandXdgOutputV1E_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandXdgOutputV1",
        "DefaultProperty",
        "data",
        "managerChanged",
        "",
        "outputChanged",
        "logicalPositionChanged",
        "logicalSizeChanged",
        "logicalGeometryChanged",
        "nameChanged",
        "descriptionChanged",
        "QQmlListProperty<QObject>",
        "manager",
        "QWaylandXdgOutputManagerV1*",
        "output",
        "QWaylandOutput*",
        "name",
        "description",
        "logicalPosition",
        "QPoint",
        "logicalSize",
        "QSize",
        "logicalGeometry",
        "QRect"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'managerChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'logicalPositionChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'logicalSizeChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'logicalGeometryChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'descriptionChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'data'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(2, 0x80000000 | 11, QMC::Readable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag),
        // property 'manager'
        QtMocHelpers::PropertyData<QWaylandXdgOutputManagerV1*>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'output'
        QtMocHelpers::PropertyData<QWaylandOutput*>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'description'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'logicalPosition'
        QtMocHelpers::PropertyData<QPoint>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'logicalSize'
        QtMocHelpers::PropertyData<QSize>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'logicalGeometry'
        QtMocHelpers::PropertyData<QRect>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QWaylandXdgOutputV1, qt_meta_tag_ZN19QWaylandXdgOutputV1E_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QWaylandXdgOutputV1::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QWaylandXdgOutputV1E_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QWaylandXdgOutputV1E_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19QWaylandXdgOutputV1E_t>.metaTypes,
    nullptr
} };

void QWaylandXdgOutputV1::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QWaylandXdgOutputV1 *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->managerChanged(); break;
        case 1: _t->outputChanged(); break;
        case 2: _t->logicalPositionChanged(); break;
        case 3: _t->logicalSizeChanged(); break;
        case 4: _t->logicalGeometryChanged(); break;
        case 5: _t->nameChanged(); break;
        case 6: _t->descriptionChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QWaylandXdgOutputV1::*)()>(_a, &QWaylandXdgOutputV1::managerChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandXdgOutputV1::*)()>(_a, &QWaylandXdgOutputV1::outputChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandXdgOutputV1::*)()>(_a, &QWaylandXdgOutputV1::logicalPositionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandXdgOutputV1::*)()>(_a, &QWaylandXdgOutputV1::logicalSizeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandXdgOutputV1::*)()>(_a, &QWaylandXdgOutputV1::logicalGeometryChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandXdgOutputV1::*)()>(_a, &QWaylandXdgOutputV1::nameChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandXdgOutputV1::*)()>(_a, &QWaylandXdgOutputV1::descriptionChanged, 6))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWaylandXdgOutputManagerV1* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->data(); break;
        case 1: *reinterpret_cast<QWaylandXdgOutputManagerV1**>(_v) = _t->manager(); break;
        case 2: *reinterpret_cast<QWaylandOutput**>(_v) = _t->output(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->description(); break;
        case 5: *reinterpret_cast<QPoint*>(_v) = _t->logicalPosition(); break;
        case 6: *reinterpret_cast<QSize*>(_v) = _t->logicalSize(); break;
        case 7: *reinterpret_cast<QRect*>(_v) = _t->logicalGeometry(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 3: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setDescription(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setLogicalPosition(*reinterpret_cast<QPoint*>(_v)); break;
        case 6: _t->setLogicalSize(*reinterpret_cast<QSize*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QWaylandXdgOutputV1::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QWaylandXdgOutputV1::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QWaylandXdgOutputV1E_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QWaylandXdgOutputV1::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void QWaylandXdgOutputV1::managerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QWaylandXdgOutputV1::outputChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QWaylandXdgOutputV1::logicalPositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QWaylandXdgOutputV1::logicalSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QWaylandXdgOutputV1::logicalGeometryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QWaylandXdgOutputV1::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QWaylandXdgOutputV1::descriptionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
