/* Generated by wayland-scanner 1.26.0 */

/*
 * Copyright © 2020 The Qt Company Ltd.
 *
 * Permission to use, copy, modify, distribute, and sell this
 * software and its documentation for any purpose is hereby granted
 * without fee, provided that the above copyright notice appear in
 * all copies and that both that copyright notice and this permission
 * notice appear in supporting documentation, and that the name of
 * the copyright holders not be used in advertising or publicity
 * pertaining to distribution of the software without specific,
 * written prior permission.  The copyright holders make no
 * representations about the suitability of this software for any
 * purpose.  It is provided "as is" without express or implied
 * warranty.
 *
 * THE COPYRIGHT HOLDERS DISCLAIM ALL WARRANTIES WITH REGARD TO THIS
 * SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS, IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
 * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
 * THIS SOFTWARE.
 */

#include <stdbool.h>
#include <stdlib.h>
#include <stdint.h>
#include "wayland-util.h"

#ifndef __has_attribute
# define __has_attribute(x) 0  /* Compatibility with non-clang compilers. */
#endif

#if (__has_attribute(visibility) || defined(__GNUC__) && __GNUC__ >= 4)
#define WL_PRIVATE __attribute__ ((visibility("hidden")))
#else
#define WL_PRIVATE
#endif

extern const struct wl_interface qt_text_input_method_v1_interface;
extern const struct wl_interface wl_seat_interface;
extern const struct wl_interface wl_surface_interface;

static const struct wl_interface *qt_text_input_method_unstable_v1_types[] = {
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	&wl_surface_interface,
	&wl_surface_interface,
	&wl_surface_interface,
	&wl_surface_interface,
	&qt_text_input_method_v1_interface,
	&wl_seat_interface,
};

static const struct wl_message qt_text_input_method_v1_requests[] = {
	{ "destroy", "", qt_text_input_method_unstable_v1_types + 0 },
	{ "enable", "o", qt_text_input_method_unstable_v1_types + 9 },
	{ "disable", "o", qt_text_input_method_unstable_v1_types + 10 },
	{ "reset", "", qt_text_input_method_unstable_v1_types + 0 },
	{ "commit", "", qt_text_input_method_unstable_v1_types + 0 },
	{ "invoke_action", "ii", qt_text_input_method_unstable_v1_types + 0 },
	{ "update_hints", "i", qt_text_input_method_unstable_v1_types + 0 },
	{ "update_cursor_rectangle", "iiii", qt_text_input_method_unstable_v1_types + 0 },
	{ "update_cursor_position", "i", qt_text_input_method_unstable_v1_types + 0 },
	{ "update_surrounding_text", "si", qt_text_input_method_unstable_v1_types + 0 },
	{ "update_anchor_position", "i", qt_text_input_method_unstable_v1_types + 0 },
	{ "update_absolute_position", "i", qt_text_input_method_unstable_v1_types + 0 },
	{ "update_preferred_language", "s", qt_text_input_method_unstable_v1_types + 0 },
	{ "start_update", "i", qt_text_input_method_unstable_v1_types + 0 },
	{ "end_update", "", qt_text_input_method_unstable_v1_types + 0 },
	{ "show_input_panel", "", qt_text_input_method_unstable_v1_types + 0 },
	{ "hide_input_panel", "", qt_text_input_method_unstable_v1_types + 0 },
	{ "acknowledge_input_method", "", qt_text_input_method_unstable_v1_types + 0 },
};

static const struct wl_message qt_text_input_method_v1_events[] = {
	{ "enter", "o", qt_text_input_method_unstable_v1_types + 11 },
	{ "leave", "o", qt_text_input_method_unstable_v1_types + 12 },
	{ "key", "iiiiiiiis", qt_text_input_method_unstable_v1_types + 0 },
	{ "start_input_method_event", "ui", qt_text_input_method_unstable_v1_types + 0 },
	{ "input_method_event_attribute", "uiiis", qt_text_input_method_unstable_v1_types + 0 },
	{ "end_input_method_event", "ussii", qt_text_input_method_unstable_v1_types + 0 },
	{ "visible_changed", "i", qt_text_input_method_unstable_v1_types + 0 },
	{ "keyboard_rectangle_changed", "ffff", qt_text_input_method_unstable_v1_types + 0 },
	{ "locale_changed", "s", qt_text_input_method_unstable_v1_types + 0 },
	{ "input_direction_changed", "i", qt_text_input_method_unstable_v1_types + 0 },
};

WL_PRIVATE const struct wl_interface qt_text_input_method_v1_interface = {
	"qt_text_input_method_v1", 1,
	18, qt_text_input_method_v1_requests,
	10, qt_text_input_method_v1_events,
};

static const struct wl_message qt_text_input_method_manager_v1_requests[] = {
	{ "destroy", "", qt_text_input_method_unstable_v1_types + 0 },
	{ "get_text_input_method", "no", qt_text_input_method_unstable_v1_types + 13 },
};

WL_PRIVATE const struct wl_interface qt_text_input_method_manager_v1_interface = {
	"qt_text_input_method_manager_v1", 1,
	2, qt_text_input_method_manager_v1_requests,
	0, NULL,
};

