/****************************************************************************
** Meta object code from reading C++ file 'qwaylandqtshell.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../qtwayland/src/imports/compositor-extensions/qtshell/qwaylandqtshell.h"
#include "qwaylandsurface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qwaylandqtshell.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15QWaylandQtShellE_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandQtShell::qt_create_metaobjectdata<qt_meta_tag_ZN15QWaylandQtShellE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandQtShell",
        "qtShellSurfaceRequested",
        "",
        "QWaylandSurface*",
        "surface",
        "QWaylandResource",
        "resource",
        "qtShellSurfaceCreated",
        "QWaylandQtShellSurface*",
        "qtShellSurface",
        "chromeActivated",
        "chromeDeactivated"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'qtShellSurfaceRequested'
        QtMocHelpers::SignalData<void(QWaylandSurface *, const QWaylandResource &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'qtShellSurfaceCreated'
        QtMocHelpers::SignalData<void(QWaylandQtShellSurface *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'chromeActivated'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'chromeDeactivated'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QWaylandQtShell, qt_meta_tag_ZN15QWaylandQtShellE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QWaylandQtShell::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandCompositorExtensionTemplate<QWaylandQtShell>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15QWaylandQtShellE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15QWaylandQtShellE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15QWaylandQtShellE_t>.metaTypes,
    nullptr
} };

void QWaylandQtShell::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QWaylandQtShell *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->qtShellSurfaceRequested((*reinterpret_cast<std::add_pointer_t<QWaylandSurface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWaylandResource>>(_a[2]))); break;
        case 1: _t->qtShellSurfaceCreated((*reinterpret_cast<std::add_pointer_t<QWaylandQtShellSurface*>>(_a[1]))); break;
        case 2: _t->chromeActivated(); break;
        case 3: _t->chromeDeactivated(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWaylandResource >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWaylandSurface* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWaylandQtShellSurface* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShell::*)(QWaylandSurface * , const QWaylandResource & )>(_a, &QWaylandQtShell::qtShellSurfaceRequested, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShell::*)(QWaylandQtShellSurface * )>(_a, &QWaylandQtShell::qtShellSurfaceCreated, 1))
            return;
    }
}

const QMetaObject *QWaylandQtShell::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QWaylandQtShell::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15QWaylandQtShellE_t>.strings))
        return static_cast<void*>(this);
    return QWaylandCompositorExtensionTemplate<QWaylandQtShell>::qt_metacast(_clname);
}

int QWaylandQtShell::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandCompositorExtensionTemplate<QWaylandQtShell>::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void QWaylandQtShell::qtShellSurfaceRequested(QWaylandSurface * _t1, const QWaylandResource & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void QWaylandQtShell::qtShellSurfaceCreated(QWaylandQtShellSurface * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN29QWaylandQtShellQuickExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandQtShellQuickExtension::qt_create_metaobjectdata<qt_meta_tag_ZN29QWaylandQtShellQuickExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandQtShellQuickExtension",
        "DefaultProperty",
        "data",
        "QML.Element",
        "QtShell",
        "QML.AddedInVersion",
        "256",
        "QQmlListProperty<QObject>"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'data'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(2, 0x80000000 | 7, QMC::Readable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QWaylandQtShellQuickExtension, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QWaylandQtShellQuickExtension::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandQtShell::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QWaylandQtShellQuickExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QWaylandQtShellQuickExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29QWaylandQtShellQuickExtensionE_t>.metaTypes,
    nullptr
} };

void QWaylandQtShellQuickExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QWaylandQtShellQuickExtension *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->data(); break;
        default: break;
        }
    }
}

const QMetaObject *QWaylandQtShellQuickExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QWaylandQtShellQuickExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QWaylandQtShellQuickExtensionE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QWaylandQtShell::qt_metacast(_clname);
}

int QWaylandQtShellQuickExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandQtShell::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN22QWaylandQtShellSurfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandQtShellSurface::qt_create_metaobjectdata<qt_meta_tag_ZN22QWaylandQtShellSurfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandQtShellSurface",
        "QML.Element",
        "QtShellSurface",
        "QML.AddedInVersion",
        "256",
        "DefaultProperty",
        "data",
        "surfaceChanged",
        "",
        "windowFlagsChanged",
        "windowStateChanged",
        "windowGeometryChanged",
        "minimumSizeChanged",
        "maximumSizeChanged",
        "positionAutomaticChanged",
        "startMove",
        "startResize",
        "Qt::Edges",
        "edges",
        "windowTitleChanged",
        "frameMarginChanged",
        "raiseRequested",
        "lowerRequested",
        "activeChanged",
        "capabilitiesChanged",
        "surfaceCommitted",
        "requestWindowGeometry",
        "windowState",
        "QRect",
        "windowGeometry",
        "sendClose",
        "QQmlListProperty<QObject>",
        "surface",
        "QWaylandSurface*",
        "windowFlags",
        "windowTitle",
        "windowPosition",
        "QPoint",
        "positionAutomatic",
        "minimumSize",
        "QSize",
        "maximumSize",
        "frameMarginLeft",
        "frameMarginRight",
        "frameMarginTop",
        "frameMarginBottom",
        "active",
        "capabilities",
        "CapabilityFlags",
        "CapabilityFlag",
        "InteractiveMove",
        "InteractiveResize"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'surfaceChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'windowFlagsChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'windowStateChanged'
        QtMocHelpers::SignalData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'windowGeometryChanged'
        QtMocHelpers::SignalData<void()>(11, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minimumSizeChanged'
        QtMocHelpers::SignalData<void()>(12, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maximumSizeChanged'
        QtMocHelpers::SignalData<void()>(13, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'positionAutomaticChanged'
        QtMocHelpers::SignalData<void()>(14, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'startMove'
        QtMocHelpers::SignalData<void()>(15, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'startResize'
        QtMocHelpers::SignalData<void(Qt::Edges)>(16, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Signal 'windowTitleChanged'
        QtMocHelpers::SignalData<void()>(19, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'frameMarginChanged'
        QtMocHelpers::SignalData<void()>(20, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'raiseRequested'
        QtMocHelpers::SignalData<void()>(21, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lowerRequested'
        QtMocHelpers::SignalData<void()>(22, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeChanged'
        QtMocHelpers::SignalData<void()>(23, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'capabilitiesChanged'
        QtMocHelpers::SignalData<void()>(24, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'surfaceCommitted'
        QtMocHelpers::SlotData<void()>(25, 8, QMC::AccessPrivate, QMetaType::Void),
        // Method 'requestWindowGeometry'
        QtMocHelpers::MethodData<void(uint, const QRect &)>(26, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 27 }, { 0x80000000 | 28, 29 },
        }}),
        // Method 'sendClose'
        QtMocHelpers::MethodData<void()>(30, 8, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'data'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(6, 0x80000000 | 31, QMC::Readable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag),
        // property 'surface'
        QtMocHelpers::PropertyData<QWaylandSurface*>(32, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'windowFlags'
        QtMocHelpers::PropertyData<uint>(34, QMetaType::UInt, QMC::DefaultPropertyFlags, 1),
        // property 'windowState'
        QtMocHelpers::PropertyData<uint>(27, QMetaType::UInt, QMC::DefaultPropertyFlags, 2),
        // property 'windowTitle'
        QtMocHelpers::PropertyData<QString>(35, QMetaType::QString, QMC::DefaultPropertyFlags, 9),
        // property 'windowGeometry'
        QtMocHelpers::PropertyData<QRect>(29, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'windowPosition'
        QtMocHelpers::PropertyData<QPoint>(36, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'positionAutomatic'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'minimumSize'
        QtMocHelpers::PropertyData<QSize>(39, 0x80000000 | 40, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'maximumSize'
        QtMocHelpers::PropertyData<QSize>(41, 0x80000000 | 40, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'frameMarginLeft'
        QtMocHelpers::PropertyData<int>(42, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'frameMarginRight'
        QtMocHelpers::PropertyData<int>(43, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'frameMarginTop'
        QtMocHelpers::PropertyData<int>(44, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'frameMarginBottom'
        QtMocHelpers::PropertyData<int>(45, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'active'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'capabilities'
        QtMocHelpers::PropertyData<CapabilityFlags>(47, 0x80000000 | 48, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 14),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'CapabilityFlag'
        QtMocHelpers::EnumData<enum CapabilityFlag>(49, 49, QMC::EnumFlags{}).add({
            {   50, CapabilityFlag::InteractiveMove },
            {   51, CapabilityFlag::InteractiveResize },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QWaylandQtShellSurface, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QWaylandQtShellSurface::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandShellSurfaceTemplate<QWaylandQtShellSurface>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QWaylandQtShellSurfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QWaylandQtShellSurfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22QWaylandQtShellSurfaceE_t>.metaTypes,
    nullptr
} };

void QWaylandQtShellSurface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QWaylandQtShellSurface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->surfaceChanged(); break;
        case 1: _t->windowFlagsChanged(); break;
        case 2: _t->windowStateChanged(); break;
        case 3: _t->windowGeometryChanged(); break;
        case 4: _t->minimumSizeChanged(); break;
        case 5: _t->maximumSizeChanged(); break;
        case 6: _t->positionAutomaticChanged(); break;
        case 7: _t->startMove(); break;
        case 8: _t->startResize((*reinterpret_cast<std::add_pointer_t<Qt::Edges>>(_a[1]))); break;
        case 9: _t->windowTitleChanged(); break;
        case 10: _t->frameMarginChanged(); break;
        case 11: _t->raiseRequested(); break;
        case 12: _t->lowerRequested(); break;
        case 13: _t->activeChanged(); break;
        case 14: _t->capabilitiesChanged(); break;
        case 15: _t->surfaceCommitted(); break;
        case 16: _t->requestWindowGeometry((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QRect>>(_a[2]))); break;
        case 17: _t->sendClose(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellSurface::*)()>(_a, &QWaylandQtShellSurface::surfaceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellSurface::*)()>(_a, &QWaylandQtShellSurface::windowFlagsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellSurface::*)()>(_a, &QWaylandQtShellSurface::windowStateChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellSurface::*)()>(_a, &QWaylandQtShellSurface::windowGeometryChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellSurface::*)()>(_a, &QWaylandQtShellSurface::minimumSizeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellSurface::*)()>(_a, &QWaylandQtShellSurface::maximumSizeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellSurface::*)()>(_a, &QWaylandQtShellSurface::positionAutomaticChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellSurface::*)()>(_a, &QWaylandQtShellSurface::startMove, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellSurface::*)(Qt::Edges )>(_a, &QWaylandQtShellSurface::startResize, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellSurface::*)()>(_a, &QWaylandQtShellSurface::windowTitleChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellSurface::*)()>(_a, &QWaylandQtShellSurface::frameMarginChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellSurface::*)()>(_a, &QWaylandQtShellSurface::raiseRequested, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellSurface::*)()>(_a, &QWaylandQtShellSurface::lowerRequested, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellSurface::*)()>(_a, &QWaylandQtShellSurface::activeChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQtShellSurface::*)()>(_a, &QWaylandQtShellSurface::capabilitiesChanged, 14))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWaylandSurface* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->data(); break;
        case 1: *reinterpret_cast<QWaylandSurface**>(_v) = _t->surface(); break;
        case 2: *reinterpret_cast<uint*>(_v) = _t->windowFlags(); break;
        case 3: *reinterpret_cast<uint*>(_v) = _t->windowState(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->windowTitle(); break;
        case 5: *reinterpret_cast<QRect*>(_v) = _t->windowGeometry(); break;
        case 6: *reinterpret_cast<QPoint*>(_v) = _t->windowPosition(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->positionAutomatic(); break;
        case 8: *reinterpret_cast<QSize*>(_v) = _t->minimumSize(); break;
        case 9: *reinterpret_cast<QSize*>(_v) = _t->maximumSize(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->frameMarginLeft(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->frameMarginRight(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->frameMarginTop(); break;
        case 13: *reinterpret_cast<int*>(_v) = _t->frameMarginBottom(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->active(); break;
        case 15: *reinterpret_cast<CapabilityFlags*>(_v) = _t->capabilities(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 6: _t->setWindowPosition(*reinterpret_cast<QPoint*>(_v)); break;
        case 10: _t->setFrameMarginLeft(*reinterpret_cast<int*>(_v)); break;
        case 11: _t->setFrameMarginRight(*reinterpret_cast<int*>(_v)); break;
        case 12: _t->setFrameMarginTop(*reinterpret_cast<int*>(_v)); break;
        case 13: _t->setFrameMarginBottom(*reinterpret_cast<int*>(_v)); break;
        case 14: _t->setActive(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->setCapabilities(*reinterpret_cast<CapabilityFlags*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QWaylandQtShellSurface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QWaylandQtShellSurface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QWaylandQtShellSurfaceE_t>.strings))
        return static_cast<void*>(this);
    return QWaylandShellSurfaceTemplate<QWaylandQtShellSurface>::qt_metacast(_clname);
}

int QWaylandQtShellSurface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandShellSurfaceTemplate<QWaylandQtShellSurface>::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void QWaylandQtShellSurface::surfaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QWaylandQtShellSurface::windowFlagsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QWaylandQtShellSurface::windowStateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QWaylandQtShellSurface::windowGeometryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QWaylandQtShellSurface::minimumSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QWaylandQtShellSurface::maximumSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QWaylandQtShellSurface::positionAutomaticChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QWaylandQtShellSurface::startMove()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QWaylandQtShellSurface::startResize(Qt::Edges _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void QWaylandQtShellSurface::windowTitleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QWaylandQtShellSurface::frameMarginChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void QWaylandQtShellSurface::raiseRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void QWaylandQtShellSurface::lowerRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void QWaylandQtShellSurface::activeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void QWaylandQtShellSurface::capabilitiesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}
QT_WARNING_POP
