/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<plugin_p.h>)
#  include <plugin_p.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_QtWayland_Compositor_TextureSharingExtension()
{
    qmlRegisterModule("QtWayland.Compositor.TextureSharingExtension", 1, 0);
    qmlRegisterModule("QtWayland.Compositor.TextureSharingExtension", 1, 254);
    qmlRegisterModule("QtWayland.Compositor.TextureSharingExtension", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    QMetaType::fromType<QWaylandTextureSharingExtension *>().id();
    qmlRegisterTypesAndRevisions<QWaylandTextureSharingExtensionQuickExtensionBase2Foreign>("QtWayland.Compositor.TextureSharingExtension", 254);
    QMetaType::fromType<QWaylandTextureSharingExtensionQuickExtensionBase2Foreign *>().id();
    qmlRegisterTypesAndRevisions<QWaylandTextureSharingExtensionQuickExtensionBaseForeign>("QtWayland.Compositor.TextureSharingExtension", 254);
    QMetaType::fromType<QWaylandTextureSharingExtensionQuickExtensionBaseForeign *>().id();
    qmlRegisterTypesAndRevisions<QWaylandTextureSharingExtensionQuickExtensionForeign>("QtWayland.Compositor.TextureSharingExtension", 254);
    QMetaType::fromType<QWaylandTextureSharingExtensionQuickExtensionForeign *>().id();
    QT_WARNING_POP
    qmlRegisterModule("QtWayland.Compositor.TextureSharingExtension", 254, 254);
}

static const QQmlModuleRegistration qtWaylandCompositorTextureSharingExtensionRegistration("QtWayland.Compositor.TextureSharingExtension", qml_register_types_QtWayland_Compositor_TextureSharingExtension);
