/****************************************************************************
** Meta object code from reading C++ file 'qwaylandwlshell.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtwayland/src/compositor/extensions/qwaylandwlshell.h"
#include "qwaylandsurface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qwaylandwlshell.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15QWaylandWlShellE_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandWlShell::qt_create_metaobjectdata<qt_meta_tag_ZN15QWaylandWlShellE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandWlShell",
        "wlShellSurfaceRequested",
        "",
        "QWaylandSurface*",
        "surface",
        "QWaylandResource",
        "resource",
        "wlShellSurfaceCreated",
        "QWaylandWlShellSurface*",
        "shellSurface",
        "closeAllPopups"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'wlShellSurfaceRequested'
        QtMocHelpers::SignalData<void(QWaylandSurface *, const QWaylandResource &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'wlShellSurfaceCreated'
        QtMocHelpers::SignalData<void(QWaylandWlShellSurface *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'closeAllPopups'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QWaylandWlShell, qt_meta_tag_ZN15QWaylandWlShellE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QWaylandWlShell::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandShellTemplate<QWaylandWlShell>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15QWaylandWlShellE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15QWaylandWlShellE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15QWaylandWlShellE_t>.metaTypes,
    nullptr
} };

void QWaylandWlShell::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QWaylandWlShell *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->wlShellSurfaceRequested((*reinterpret_cast<std::add_pointer_t<QWaylandSurface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWaylandResource>>(_a[2]))); break;
        case 1: _t->wlShellSurfaceCreated((*reinterpret_cast<std::add_pointer_t<QWaylandWlShellSurface*>>(_a[1]))); break;
        case 2: _t->closeAllPopups(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWaylandResource >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWaylandWlShellSurface* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QWaylandWlShell::*)(QWaylandSurface * , const QWaylandResource & )>(_a, &QWaylandWlShell::wlShellSurfaceRequested, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandWlShell::*)(QWaylandWlShellSurface * )>(_a, &QWaylandWlShell::wlShellSurfaceCreated, 1))
            return;
    }
}

const QMetaObject *QWaylandWlShell::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QWaylandWlShell::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15QWaylandWlShellE_t>.strings))
        return static_cast<void*>(this);
    return QWaylandShellTemplate<QWaylandWlShell>::qt_metacast(_clname);
}

int QWaylandWlShell::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandShellTemplate<QWaylandWlShell>::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void QWaylandWlShell::wlShellSurfaceRequested(QWaylandSurface * _t1, const QWaylandResource & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void QWaylandWlShell::wlShellSurfaceCreated(QWaylandWlShellSurface * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN22QWaylandWlShellSurfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandWlShellSurface::qt_create_metaobjectdata<qt_meta_tag_ZN22QWaylandWlShellSurfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandWlShellSurface",
        "DefaultProperty",
        "data",
        "surfaceChanged",
        "",
        "shellChanged",
        "titleChanged",
        "classNameChanged",
        "pong",
        "startMove",
        "QWaylandSeat*",
        "seat",
        "startResize",
        "ResizeEdge",
        "edges",
        "setDefaultToplevel",
        "setTransient",
        "QWaylandSurface*",
        "parentSurface",
        "QPoint",
        "relativeToParent",
        "inactive",
        "setFullScreen",
        "FullScreenMethod",
        "method",
        "framerate",
        "QWaylandOutput*",
        "output",
        "setPopup",
        "setMaximized",
        "ping",
        "initialize",
        "QWaylandWlShell*",
        "shell",
        "surface",
        "QWaylandResource",
        "resource",
        "sizeForResize",
        "QSize",
        "QSizeF",
        "size",
        "QPointF",
        "delta",
        "sendConfigure",
        "sendPopupDone",
        "QQmlListProperty<QObject>",
        "title",
        "className",
        "DefaultFullScreen",
        "ScaleFullScreen",
        "DriverFullScreen",
        "FillFullScreen",
        "NoneEdge",
        "TopEdge",
        "BottomEdge",
        "LeftEdge",
        "TopLeftEdge",
        "BottomLeftEdge",
        "RightEdge",
        "TopRightEdge",
        "BottomRightEdge"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'surfaceChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shellChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'classNameChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pong'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'startMove'
        QtMocHelpers::SignalData<void(QWaylandSeat *)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'startResize'
        QtMocHelpers::SignalData<void(QWaylandSeat *, enum ResizeEdge)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { 0x80000000 | 13, 14 },
        }}),
        // Signal 'setDefaultToplevel'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'setTransient'
        QtMocHelpers::SignalData<void(QWaylandSurface *, const QPoint &, bool)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 }, { 0x80000000 | 19, 20 }, { QMetaType::Bool, 21 },
        }}),
        // Signal 'setFullScreen'
        QtMocHelpers::SignalData<void(enum FullScreenMethod, uint, QWaylandOutput *)>(22, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 }, { QMetaType::UInt, 25 }, { 0x80000000 | 26, 27 },
        }}),
        // Signal 'setPopup'
        QtMocHelpers::SignalData<void(QWaylandSeat *, QWaylandSurface *, const QPoint &)>(28, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { 0x80000000 | 17, 18 }, { 0x80000000 | 19, 20 },
        }}),
        // Signal 'setMaximized'
        QtMocHelpers::SignalData<void(QWaylandOutput *)>(29, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'ping'
        QtMocHelpers::SlotData<void()>(30, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'initialize'
        QtMocHelpers::MethodData<void(QWaylandWlShell *, QWaylandSurface *, const QWaylandResource &)>(31, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 }, { 0x80000000 | 17, 34 }, { 0x80000000 | 35, 36 },
        }}),
        // Method 'sizeForResize'
        QtMocHelpers::MethodData<QSize(const QSizeF &, const QPointF &, enum ResizeEdge)>(37, 4, QMC::AccessPublic, 0x80000000 | 38, {{
            { 0x80000000 | 39, 40 }, { 0x80000000 | 41, 42 }, { 0x80000000 | 13, 14 },
        }}),
        // Method 'sendConfigure'
        QtMocHelpers::MethodData<void(const QSize &, enum ResizeEdge)>(43, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 38, 40 }, { 0x80000000 | 13, 14 },
        }}),
        // Method 'sendPopupDone'
        QtMocHelpers::MethodData<void()>(44, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'data'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(2, 0x80000000 | 45, QMC::Readable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag),
        // property 'surface'
        QtMocHelpers::PropertyData<QWaylandSurface*>(34, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'shell'
        QtMocHelpers::PropertyData<QWaylandWlShell*>(33, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'title'
        QtMocHelpers::PropertyData<QString>(46, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'className'
        QtMocHelpers::PropertyData<QString>(47, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'FullScreenMethod'
        QtMocHelpers::EnumData<enum FullScreenMethod>(23, 23, QMC::EnumFlags{}).add({
            {   48, FullScreenMethod::DefaultFullScreen },
            {   49, FullScreenMethod::ScaleFullScreen },
            {   50, FullScreenMethod::DriverFullScreen },
            {   51, FullScreenMethod::FillFullScreen },
        }),
        // enum 'ResizeEdge'
        QtMocHelpers::EnumData<enum ResizeEdge>(13, 13, QMC::EnumFlags{}).add({
            {   52, ResizeEdge::NoneEdge },
            {   53, ResizeEdge::TopEdge },
            {   54, ResizeEdge::BottomEdge },
            {   55, ResizeEdge::LeftEdge },
            {   56, ResizeEdge::TopLeftEdge },
            {   57, ResizeEdge::BottomLeftEdge },
            {   58, ResizeEdge::RightEdge },
            {   59, ResizeEdge::TopRightEdge },
            {   60, ResizeEdge::BottomRightEdge },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QWaylandWlShellSurface, qt_meta_tag_ZN22QWaylandWlShellSurfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QWaylandWlShellSurface::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandShellSurfaceTemplate<QWaylandWlShellSurface>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QWaylandWlShellSurfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QWaylandWlShellSurfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22QWaylandWlShellSurfaceE_t>.metaTypes,
    nullptr
} };

void QWaylandWlShellSurface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QWaylandWlShellSurface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->surfaceChanged(); break;
        case 1: _t->shellChanged(); break;
        case 2: _t->titleChanged(); break;
        case 3: _t->classNameChanged(); break;
        case 4: _t->pong(); break;
        case 5: _t->startMove((*reinterpret_cast<std::add_pointer_t<QWaylandSeat*>>(_a[1]))); break;
        case 6: _t->startResize((*reinterpret_cast<std::add_pointer_t<QWaylandSeat*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum ResizeEdge>>(_a[2]))); break;
        case 7: _t->setDefaultToplevel(); break;
        case 8: _t->setTransient((*reinterpret_cast<std::add_pointer_t<QWaylandSurface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 9: _t->setFullScreen((*reinterpret_cast<std::add_pointer_t<enum FullScreenMethod>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QWaylandOutput*>>(_a[3]))); break;
        case 10: _t->setPopup((*reinterpret_cast<std::add_pointer_t<QWaylandSeat*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWaylandSurface*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[3]))); break;
        case 11: _t->setMaximized((*reinterpret_cast<std::add_pointer_t<QWaylandOutput*>>(_a[1]))); break;
        case 12: _t->ping(); break;
        case 13: _t->initialize((*reinterpret_cast<std::add_pointer_t<QWaylandWlShell*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWaylandSurface*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QWaylandResource>>(_a[3]))); break;
        case 14: { QSize _r = _t->sizeForResize((*reinterpret_cast<std::add_pointer_t<QSizeF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<enum ResizeEdge>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QSize*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->sendConfigure((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum ResizeEdge>>(_a[2]))); break;
        case 16: _t->sendPopupDone(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWaylandResource >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWaylandWlShell* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QWaylandWlShellSurface::*)()>(_a, &QWaylandWlShellSurface::surfaceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandWlShellSurface::*)()>(_a, &QWaylandWlShellSurface::shellChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandWlShellSurface::*)()>(_a, &QWaylandWlShellSurface::titleChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandWlShellSurface::*)()>(_a, &QWaylandWlShellSurface::classNameChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandWlShellSurface::*)()>(_a, &QWaylandWlShellSurface::pong, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandWlShellSurface::*)(QWaylandSeat * )>(_a, &QWaylandWlShellSurface::startMove, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandWlShellSurface::*)(QWaylandSeat * , ResizeEdge )>(_a, &QWaylandWlShellSurface::startResize, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandWlShellSurface::*)()>(_a, &QWaylandWlShellSurface::setDefaultToplevel, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandWlShellSurface::*)(QWaylandSurface * , const QPoint & , bool )>(_a, &QWaylandWlShellSurface::setTransient, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandWlShellSurface::*)(FullScreenMethod , uint , QWaylandOutput * )>(_a, &QWaylandWlShellSurface::setFullScreen, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandWlShellSurface::*)(QWaylandSeat * , QWaylandSurface * , const QPoint & )>(_a, &QWaylandWlShellSurface::setPopup, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandWlShellSurface::*)(QWaylandOutput * )>(_a, &QWaylandWlShellSurface::setMaximized, 11))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWaylandWlShell* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->data(); break;
        case 1: *reinterpret_cast<QWaylandSurface**>(_v) = _t->surface(); break;
        case 2: *reinterpret_cast<QWaylandWlShell**>(_v) = _t->shell(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->className(); break;
        default: break;
        }
    }
}

const QMetaObject *QWaylandWlShellSurface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QWaylandWlShellSurface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QWaylandWlShellSurfaceE_t>.strings))
        return static_cast<void*>(this);
    return QWaylandShellSurfaceTemplate<QWaylandWlShellSurface>::qt_metacast(_clname);
}

int QWaylandWlShellSurface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandShellSurfaceTemplate<QWaylandWlShellSurface>::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void QWaylandWlShellSurface::surfaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QWaylandWlShellSurface::shellChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QWaylandWlShellSurface::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QWaylandWlShellSurface::classNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QWaylandWlShellSurface::pong()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QWaylandWlShellSurface::startMove(QWaylandSeat * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void QWaylandWlShellSurface::startResize(QWaylandSeat * _t1, ResizeEdge _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void QWaylandWlShellSurface::setDefaultToplevel()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QWaylandWlShellSurface::setTransient(QWaylandSurface * _t1, const QPoint & _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2, _t3);
}

// SIGNAL 9
void QWaylandWlShellSurface::setFullScreen(FullScreenMethod _t1, uint _t2, QWaylandOutput * _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2, _t3);
}

// SIGNAL 10
void QWaylandWlShellSurface::setPopup(QWaylandSeat * _t1, QWaylandSurface * _t2, const QPoint & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2, _t3);
}

// SIGNAL 11
void QWaylandWlShellSurface::setMaximized(QWaylandOutput * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}
QT_WARNING_POP
