/****************************************************************************
** Meta object code from reading C++ file 'qwaylandseat.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtwayland/src/compositor/compositor_api/qwaylandseat.h"
#include "qwaylanddrag.h"
#include "qwaylandkeymap.h"
#include "qwaylandview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qwaylandseat.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12QWaylandSeatE_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandSeat::qt_create_metaobjectdata<qt_meta_tag_ZN12QWaylandSeatE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandSeat",
        "QML.Element",
        "WaylandSeat",
        "QML.AddedInVersion",
        "256",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "mouseFocusChanged",
        "QWaylandView*",
        "newFocus",
        "oldFocus",
        "keyboardFocusChanged",
        "QWaylandSurface*",
        "cursorSurfaceRequest",
        "surface",
        "hotspotX",
        "hotspotY",
        "cursorSurfaceRequested",
        "QWaylandClient*",
        "client",
        "sendKeyEvent",
        "qtKey",
        "pressed",
        "sendUnicodeKeyPressEvent",
        "unicode",
        "sendUnicodeKeyReleaseEvent",
        "sendTouchPointPressed",
        "id",
        "QPointF",
        "position",
        "sendTouchPointReleased",
        "sendTouchPointMoved",
        "sendTouchFrameEvent",
        "sendTouchCancelEvent",
        "drag",
        "QWaylandDrag*",
        "keymap",
        "QWaylandKeymap*",
        "CapabilityFlags",
        "CapabilityFlag",
        "Pointer",
        "Keyboard",
        "Touch",
        "DefaultCapabilities"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'mouseFocusChanged'
        QtMocHelpers::SignalData<void(QWaylandView *, QWaylandView *)>(9, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { 0x80000000 | 10, 12 },
        }}),
        // Signal 'keyboardFocusChanged'
        QtMocHelpers::SignalData<void(QWaylandSurface *, QWaylandSurface *)>(13, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 11 }, { 0x80000000 | 14, 12 },
        }}),
        // Signal 'cursorSurfaceRequest'
        QtMocHelpers::SignalData<void(QWaylandSurface *, int, int)>(15, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 16 }, { QMetaType::Int, 17 }, { QMetaType::Int, 18 },
        }}),
        // Signal 'cursorSurfaceRequested'
        QtMocHelpers::SignalData<void(QWaylandSurface *, int, int, QWaylandClient *)>(19, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 16 }, { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { 0x80000000 | 20, 21 },
        }}),
        // Method 'sendKeyEvent'
        QtMocHelpers::MethodData<void(int, bool)>(22, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 }, { QMetaType::Bool, 24 },
        }}),
        // Method 'sendUnicodeKeyPressEvent'
        QtMocHelpers::RevisionedMethodData<void(uint)>(25, 8, QMC::AccessPublic, 0x607, QMetaType::Void, {{
            { QMetaType::UInt, 26 },
        }}),
        // Method 'sendUnicodeKeyReleaseEvent'
        QtMocHelpers::RevisionedMethodData<void(uint)>(27, 8, QMC::AccessPublic, 0x607, QMetaType::Void, {{
            { QMetaType::UInt, 26 },
        }}),
        // Method 'sendTouchPointPressed'
        QtMocHelpers::MethodData<uint(QWaylandSurface *, int, const QPointF &)>(28, 8, QMC::AccessPublic, QMetaType::UInt, {{
            { 0x80000000 | 14, 16 }, { QMetaType::Int, 29 }, { 0x80000000 | 30, 31 },
        }}),
        // Method 'sendTouchPointReleased'
        QtMocHelpers::MethodData<uint(QWaylandSurface *, int, const QPointF &)>(32, 8, QMC::AccessPublic, QMetaType::UInt, {{
            { 0x80000000 | 14, 16 }, { QMetaType::Int, 29 }, { 0x80000000 | 30, 31 },
        }}),
        // Method 'sendTouchPointMoved'
        QtMocHelpers::MethodData<uint(QWaylandSurface *, int, const QPointF &)>(33, 8, QMC::AccessPublic, QMetaType::UInt, {{
            { 0x80000000 | 14, 16 }, { QMetaType::Int, 29 }, { 0x80000000 | 30, 31 },
        }}),
        // Method 'sendTouchFrameEvent'
        QtMocHelpers::MethodData<void(QWaylandClient *)>(34, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Method 'sendTouchCancelEvent'
        QtMocHelpers::MethodData<void(QWaylandClient *)>(35, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'drag'
        QtMocHelpers::PropertyData<QWaylandDrag*>(36, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'keymap'
        QtMocHelpers::PropertyData<QWaylandKeymap*>(38, 0x80000000 | 39, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'CapabilityFlags'
        QtMocHelpers::EnumData<CapabilityFlags>(40, 41, QMC::EnumFlags{}).add({
            {   42, CapabilityFlag::Pointer },
            {   43, CapabilityFlag::Keyboard },
            {   44, CapabilityFlag::Touch },
            {   45, CapabilityFlag::DefaultCapabilities },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<QWaylandSeat, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QWaylandSeat::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12QWaylandSeatE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12QWaylandSeatE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12QWaylandSeatE_t>.metaTypes,
    nullptr
} };

void QWaylandSeat::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QWaylandSeat *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->mouseFocusChanged((*reinterpret_cast<std::add_pointer_t<QWaylandView*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWaylandView*>>(_a[2]))); break;
        case 1: _t->keyboardFocusChanged((*reinterpret_cast<std::add_pointer_t<QWaylandSurface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWaylandSurface*>>(_a[2]))); break;
        case 2: _t->cursorSurfaceRequest((*reinterpret_cast<std::add_pointer_t<QWaylandSurface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 3: _t->cursorSurfaceRequested((*reinterpret_cast<std::add_pointer_t<QWaylandSurface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QWaylandClient*>>(_a[4]))); break;
        case 4: _t->sendKeyEvent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 5: _t->sendUnicodeKeyPressEvent((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 6: _t->sendUnicodeKeyReleaseEvent((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 7: { uint _r = _t->sendTouchPointPressed((*reinterpret_cast<std::add_pointer_t<QWaylandSurface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[3])));
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 8: { uint _r = _t->sendTouchPointReleased((*reinterpret_cast<std::add_pointer_t<QWaylandSurface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[3])));
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 9: { uint _r = _t->sendTouchPointMoved((*reinterpret_cast<std::add_pointer_t<QWaylandSurface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[3])));
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->sendTouchFrameEvent((*reinterpret_cast<std::add_pointer_t<QWaylandClient*>>(_a[1]))); break;
        case 11: _t->sendTouchCancelEvent((*reinterpret_cast<std::add_pointer_t<QWaylandClient*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWaylandView* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWaylandSurface* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWaylandSurface* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWaylandClient* >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWaylandSurface* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWaylandSurface* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWaylandSurface* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWaylandSurface* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWaylandClient* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWaylandClient* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QWaylandSeat::*)(QWaylandView * , QWaylandView * )>(_a, &QWaylandSeat::mouseFocusChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandSeat::*)(QWaylandSurface * , QWaylandSurface * )>(_a, &QWaylandSeat::keyboardFocusChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandSeat::*)(QWaylandSurface * , int , int )>(_a, &QWaylandSeat::cursorSurfaceRequest, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandSeat::*)(QWaylandSurface * , int , int , QWaylandClient * )>(_a, &QWaylandSeat::cursorSurfaceRequested, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWaylandDrag* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QWaylandDrag**>(_v) = _t->drag(); break;
        case 1: *reinterpret_cast<QWaylandKeymap**>(_v) = _t->keymap(); break;
        default: break;
        }
    }
}

const QMetaObject *QWaylandSeat::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QWaylandSeat::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12QWaylandSeatE_t>.strings))
        return static_cast<void*>(this);
    return QWaylandObject::qt_metacast(_clname);
}

int QWaylandSeat::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void QWaylandSeat::mouseFocusChanged(QWaylandView * _t1, QWaylandView * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void QWaylandSeat::keyboardFocusChanged(QWaylandSurface * _t1, QWaylandSurface * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void QWaylandSeat::cursorSurfaceRequest(QWaylandSurface * _t1, int _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void QWaylandSeat::cursorSurfaceRequested(QWaylandSurface * _t1, int _t2, int _t3, QWaylandClient * _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3, _t4);
}
QT_WARNING_POP
