// This file was generated by qtwaylandscanner
// source file is qt-shell-unstable-v1.xml

#ifndef QT_WAYLAND_QT_SHELL_UNSTABLE_V1
#define QT_WAYLAND_QT_SHELL_UNSTABLE_V1

#include "wayland-qt-shell-unstable-v1-client-protocol.h"
#include <QByteArray>
#include <QString>

struct wl_registry;

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")

namespace QtWayland {
    class  zqt_shell_surface_v1
    {
    public:
        zqt_shell_surface_v1(struct ::wl_registry *registry, uint32_t id, int version);
        zqt_shell_surface_v1(struct ::zqt_shell_surface_v1 *object);
        zqt_shell_surface_v1();

        virtual ~zqt_shell_surface_v1();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::zqt_shell_surface_v1 *object);

        struct ::zqt_shell_surface_v1 *object() { return m_zqt_shell_surface_v1; }
        const struct ::zqt_shell_surface_v1 *object() const { return m_zqt_shell_surface_v1; }
        static zqt_shell_surface_v1 *fromObject(struct ::zqt_shell_surface_v1 *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        enum window_state {
            window_state_no_state = 0,
            window_state_minimized = 1,
            window_state_maximized = 2,
            window_state_fullscreen = 4,
        };

        enum capabilities {
            capabilities_interactive_move = 1,
            capabilities_interactive_resize = 2,
        };

        void destroy();
        void reposition(int32_t x, int32_t y);
        void request_activate();
        void set_size(int32_t width, int32_t height);
        void set_minimum_size(int32_t width, int32_t height);
        void set_maximum_size(int32_t width, int32_t height);
        void set_window_title(const QString &window_title);
        void set_window_flags(uint32_t flags);
        void start_system_resize(uint32_t serial, uint32_t edge);
        void start_system_move(uint32_t serial);
        void change_window_state(uint32_t state);
        void raise();
        void lower();
        void ack_configure(uint32_t serial);

    protected:
        virtual void zqt_shell_surface_v1_resize(uint32_t serial, int32_t width, int32_t height);
        virtual void zqt_shell_surface_v1_set_position(uint32_t serial, int32_t x, int32_t y);
        virtual void zqt_shell_surface_v1_set_window_state(uint32_t serial, uint32_t state);
        virtual void zqt_shell_surface_v1_configure(uint32_t serial);
        virtual void zqt_shell_surface_v1_set_frame_margins(uint32_t left, uint32_t right, uint32_t top, uint32_t bottom);
        virtual void zqt_shell_surface_v1_close();
        virtual void zqt_shell_surface_v1_set_capabilities(uint32_t capabilities);

    private:
        void init_listener();
        static const struct zqt_shell_surface_v1_listener m_zqt_shell_surface_v1_listener;
        static void handle_resize(
            void *data,
            struct ::zqt_shell_surface_v1 *object,
            uint32_t serial,
            int32_t width,
            int32_t height);
        static void handle_set_position(
            void *data,
            struct ::zqt_shell_surface_v1 *object,
            uint32_t serial,
            int32_t x,
            int32_t y);
        static void handle_set_window_state(
            void *data,
            struct ::zqt_shell_surface_v1 *object,
            uint32_t serial,
            uint32_t state);
        static void handle_configure(
            void *data,
            struct ::zqt_shell_surface_v1 *object,
            uint32_t serial);
        static void handle_set_frame_margins(
            void *data,
            struct ::zqt_shell_surface_v1 *object,
            uint32_t left,
            uint32_t right,
            uint32_t top,
            uint32_t bottom);
        static void handle_close(
            void *data,
            struct ::zqt_shell_surface_v1 *object);
        static void handle_set_capabilities(
            void *data,
            struct ::zqt_shell_surface_v1 *object,
            uint32_t capabilities);
        struct ::zqt_shell_surface_v1 *m_zqt_shell_surface_v1;
    };

    class  zqt_shell_v1
    {
    public:
        zqt_shell_v1(struct ::wl_registry *registry, uint32_t id, int version);
        zqt_shell_v1(struct ::zqt_shell_v1 *object);
        zqt_shell_v1();

        virtual ~zqt_shell_v1();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::zqt_shell_v1 *object);

        struct ::zqt_shell_v1 *object() { return m_zqt_shell_v1; }
        const struct ::zqt_shell_v1 *object() const { return m_zqt_shell_v1; }
        static zqt_shell_v1 *fromObject(struct ::zqt_shell_v1 *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        enum error {
            error_role = 0, // wl_surface already has a different role
        };

        struct ::zqt_shell_surface_v1 *surface_create(struct ::wl_surface *surface);

    private:
        struct ::zqt_shell_v1 *m_zqt_shell_v1;
    };
}

QT_WARNING_POP
QT_END_NAMESPACE

#endif
