/****************************************************************************
** Meta object code from reading C++ file 'qwaylandquickshellsurfaceitem.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtwayland/src/compositor/extensions/qwaylandquickshellsurfaceitem.h"
#include "qwaylandshellsurface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qwaylandquickshellsurfaceitem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN29QWaylandQuickShellSurfaceItemE_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandQuickShellSurfaceItem::qt_create_metaobjectdata<qt_meta_tag_ZN29QWaylandQuickShellSurfaceItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandQuickShellSurfaceItem",
        "QML.Element",
        "ShellSurfaceItem",
        "QML.AddedInVersion",
        "256",
        "shellSurfaceChanged",
        "",
        "moveItemChanged",
        "autoCreatePopupItemsChanged",
        "staysOnTopChanged",
        "staysOnBottomChanged",
        "shellSurface",
        "QWaylandShellSurface*",
        "moveItem",
        "QQuickItem*",
        "autoCreatePopupItems",
        "staysOnTop",
        "staysOnBottom"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'shellSurfaceChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'moveItemChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoCreatePopupItemsChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'staysOnTopChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'staysOnBottomChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'shellSurface'
        QtMocHelpers::PropertyData<QWaylandShellSurface*>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'moveItem'
        QtMocHelpers::PropertyData<QQuickItem*>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'autoCreatePopupItems'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'staysOnTop'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'staysOnBottom'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QWaylandQuickShellSurfaceItem, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QWaylandQuickShellSurfaceItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QWaylandQuickShellSurfaceItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QWaylandQuickShellSurfaceItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29QWaylandQuickShellSurfaceItemE_t>.metaTypes,
    nullptr
} };

void QWaylandQuickShellSurfaceItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QWaylandQuickShellSurfaceItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->shellSurfaceChanged(); break;
        case 1: _t->moveItemChanged(); break;
        case 2: _t->autoCreatePopupItemsChanged(); break;
        case 3: _t->staysOnTopChanged(); break;
        case 4: _t->staysOnBottomChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QWaylandQuickShellSurfaceItem::*)()>(_a, &QWaylandQuickShellSurfaceItem::shellSurfaceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQuickShellSurfaceItem::*)()>(_a, &QWaylandQuickShellSurfaceItem::moveItemChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQuickShellSurfaceItem::*)()>(_a, &QWaylandQuickShellSurfaceItem::autoCreatePopupItemsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQuickShellSurfaceItem::*)()>(_a, &QWaylandQuickShellSurfaceItem::staysOnTopChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QWaylandQuickShellSurfaceItem::*)()>(_a, &QWaylandQuickShellSurfaceItem::staysOnBottomChanged, 4))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QWaylandShellSurface**>(_v) = _t->shellSurface(); break;
        case 1: *reinterpret_cast<QQuickItem**>(_v) = _t->moveItem(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->autoCreatePopupItems(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->staysOnTop(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->staysOnBottom(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setShellSurface(*reinterpret_cast<QWaylandShellSurface**>(_v)); break;
        case 1: _t->setMoveItem(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 2: _t->setAutoCreatePopupItems(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setStaysOnTop(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setStaysOnBottom(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QWaylandQuickShellSurfaceItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QWaylandQuickShellSurfaceItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QWaylandQuickShellSurfaceItemE_t>.strings))
        return static_cast<void*>(this);
    return QWaylandQuickItem::qt_metacast(_clname);
}

int QWaylandQuickShellSurfaceItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void QWaylandQuickShellSurfaceItem::shellSurfaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QWaylandQuickShellSurfaceItem::moveItemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QWaylandQuickShellSurfaceItem::autoCreatePopupItemsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QWaylandQuickShellSurfaceItem::staysOnTopChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QWaylandQuickShellSurfaceItem::staysOnBottomChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
