/****************************************************************************
** Meta object code from reading C++ file 'qwaylandcompositorxdgshell_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../qtwayland/src/imports/compositor-extensions/xdgshell/qwaylandcompositorxdgshell_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qwaylandcompositorxdgshell_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN30QWaylandXdgShellQuickExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandXdgShellQuickExtension::qt_create_metaobjectdata<qt_meta_tag_ZN30QWaylandXdgShellQuickExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandXdgShellQuickExtension",
        "DefaultProperty",
        "data",
        "QML.Element",
        "XdgShell",
        "QML.AddedInVersion",
        "259",
        "QQmlListProperty<QObject>"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'data'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(2, 0x80000000 | 7, QMC::Readable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QWaylandXdgShellQuickExtension, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QWaylandXdgShellQuickExtension::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandXdgShell::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30QWaylandXdgShellQuickExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30QWaylandXdgShellQuickExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN30QWaylandXdgShellQuickExtensionE_t>.metaTypes,
    nullptr
} };

void QWaylandXdgShellQuickExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QWaylandXdgShellQuickExtension *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->data(); break;
        default: break;
        }
    }
}

const QMetaObject *QWaylandXdgShellQuickExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QWaylandXdgShellQuickExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30QWaylandXdgShellQuickExtensionE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QWaylandXdgShell::qt_metacast(_clname);
}

int QWaylandXdgShellQuickExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandXdgShell::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN44QWaylandXdgDecorationManagerV1QuickExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandXdgDecorationManagerV1QuickExtension::qt_create_metaobjectdata<qt_meta_tag_ZN44QWaylandXdgDecorationManagerV1QuickExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandXdgDecorationManagerV1QuickExtension",
        "DefaultProperty",
        "data",
        "QML.Element",
        "XdgDecorationManagerV1",
        "QML.AddedInVersion",
        "259",
        "QQmlListProperty<QObject>"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'data'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(2, 0x80000000 | 7, QMC::Readable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QWaylandXdgDecorationManagerV1QuickExtension, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QWaylandXdgDecorationManagerV1QuickExtension::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandXdgDecorationManagerV1::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN44QWaylandXdgDecorationManagerV1QuickExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN44QWaylandXdgDecorationManagerV1QuickExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN44QWaylandXdgDecorationManagerV1QuickExtensionE_t>.metaTypes,
    nullptr
} };

void QWaylandXdgDecorationManagerV1QuickExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QWaylandXdgDecorationManagerV1QuickExtension *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->data(); break;
        default: break;
        }
    }
}

const QMetaObject *QWaylandXdgDecorationManagerV1QuickExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QWaylandXdgDecorationManagerV1QuickExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN44QWaylandXdgDecorationManagerV1QuickExtensionE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QWaylandXdgDecorationManagerV1::qt_metacast(_clname);
}

int QWaylandXdgDecorationManagerV1QuickExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandXdgDecorationManagerV1::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN40QWaylandXdgOutputManagerV1QuickExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandXdgOutputManagerV1QuickExtension::qt_create_metaobjectdata<qt_meta_tag_ZN40QWaylandXdgOutputManagerV1QuickExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandXdgOutputManagerV1QuickExtension",
        "DefaultProperty",
        "data",
        "QML.Element",
        "XdgOutputManagerV1",
        "QML.AddedInVersion",
        "270",
        "QQmlListProperty<QObject>"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'data'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(2, 0x80000000 | 7, QMC::Readable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QWaylandXdgOutputManagerV1QuickExtension, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QWaylandXdgOutputManagerV1QuickExtension::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandXdgOutputManagerV1::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN40QWaylandXdgOutputManagerV1QuickExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN40QWaylandXdgOutputManagerV1QuickExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN40QWaylandXdgOutputManagerV1QuickExtensionE_t>.metaTypes,
    nullptr
} };

void QWaylandXdgOutputManagerV1QuickExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QWaylandXdgOutputManagerV1QuickExtension *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->data(); break;
        default: break;
        }
    }
}

const QMetaObject *QWaylandXdgOutputManagerV1QuickExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QWaylandXdgOutputManagerV1QuickExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN40QWaylandXdgOutputManagerV1QuickExtensionE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QWaylandXdgOutputManagerV1::qt_metacast(_clname);
}

int QWaylandXdgOutputManagerV1QuickExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandXdgOutputManagerV1::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN25QWaylandXdgSurfaceForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandXdgSurfaceForeign::qt_create_metaobjectdata<qt_meta_tag_ZN25QWaylandXdgSurfaceForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandXdgSurfaceForeign",
        "QML.Foreign",
        "QWaylandXdgSurface",
        "QML.Element",
        "XdgSurface",
        "QML.AddedInVersion",
        "259"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QWaylandXdgSurfaceForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QWaylandXdgSurfaceForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25QWaylandXdgSurfaceForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25QWaylandXdgSurfaceForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25QWaylandXdgSurfaceForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN26QWaylandXdgTopLevelForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandXdgTopLevelForeign::qt_create_metaobjectdata<qt_meta_tag_ZN26QWaylandXdgTopLevelForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandXdgTopLevelForeign",
        "QML.Foreign",
        "QWaylandXdgToplevel",
        "QML.Element",
        "XdgToplevel",
        "QML.AddedInVersion",
        "259",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Cannot create instance of XdgShellToplevel"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
            {    9,   10 },
    });
    return QtMocHelpers::metaObjectData<QWaylandXdgTopLevelForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QWaylandXdgTopLevelForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26QWaylandXdgTopLevelForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26QWaylandXdgTopLevelForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26QWaylandXdgTopLevelForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN23QWaylandXdgPopupForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandXdgPopupForeign::qt_create_metaobjectdata<qt_meta_tag_ZN23QWaylandXdgPopupForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandXdgPopupForeign",
        "QML.Foreign",
        "QWaylandXdgPopup",
        "QML.Element",
        "XdgPopup",
        "QML.AddedInVersion",
        "259",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Cannot create instance of XdgShellPopup"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
            {    9,   10 },
    });
    return QtMocHelpers::metaObjectData<QWaylandXdgPopupForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QWaylandXdgPopupForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23QWaylandXdgPopupForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23QWaylandXdgPopupForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23QWaylandXdgPopupForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN31QWaylandQuickXdgOutputV1ForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto QWaylandQuickXdgOutputV1Foreign::qt_create_metaobjectdata<qt_meta_tag_ZN31QWaylandQuickXdgOutputV1ForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QWaylandQuickXdgOutputV1Foreign",
        "QML.Foreign",
        "QWaylandQuickXdgOutputV1",
        "QML.Element",
        "XdgOutputV1",
        "QML.AddedInVersion",
        "270"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QWaylandQuickXdgOutputV1Foreign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QWaylandQuickXdgOutputV1Foreign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31QWaylandQuickXdgOutputV1ForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31QWaylandQuickXdgOutputV1ForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN31QWaylandQuickXdgOutputV1ForeignE_t>.metaTypes,
    nullptr
} };

QT_WARNING_POP
